@@ -8,10 +8,7 @@ function octavia_install {
     setup_develop $OCTAVIA_DIR
     if [ $OCTAVIA_NODE == 'main' ] || [ $OCTAVIA_NODE == 'standalone' ] ; then
         if ! [ "$DISABLE_AMP_IMAGE_BUILD" == 'True' ]; then
-            if [[ ${DISTRO} =~ "rhel7" ]]; then
-                # Installing qemu would bring in the default OS qemu package,
-                # which is too old for Pike and later releases
-                # See https://review.opendev.org/#/c/438325 for details
+            if [[ ${DISTRO} =~ (rhel|centos) ]]; then
                 install_package qemu-kvm
             else
                 install_package qemu
@@ -38,6 +35,16 @@ function octavia_lib_install {
     fi
 }
 
+function install_diskimage_builder {
+    if use_library_from_git "diskimage-builder"; then
+        GITREPO["diskimage-builder"]=$DISKIMAGE_BUILDER_REPO_URL
+        GITDIR["diskimage-builder"]=$DISKIMAGE_BUILDER_DIR
+        GITBRANCH["diskimage-builder"]=$DISKIMAGE_BUILDER_REPO_REF
+        git_clone_by_name "diskimage-builder"
+        setup_dev_lib -bindep "diskimage-builder"
+    fi
+}
+
 function set_octavia_worker_image_owner_id {
     image_id=$(openstack image list --property name=${OCTAVIA_AMP_IMAGE_NAME} -f value -c ID)
     owner_id=$(openstack image show ${image_id} -c owner -f value)
@@ -45,6 +52,9 @@ function set_octavia_worker_image_owner_id {
 }
 
 function build_octavia_worker_image {
+    # set up diskimage-builder if we need to
+    install_diskimage_builder
+
     # Pull in DIB local elements if they are defined in devstack
     if [ -n "$DIB_LOCAL_ELEMENTS" ]; then
         export DIB_LOCAL_ELEMENTS=$DIB_LOCAL_ELEMENTS
@@ -98,20 +108,7 @@ function build_octavia_worker_image {
         fi
         sudo mkdir -m755 ${dib_logs}
         sudo chown $STACK_USER ${dib_logs}
-        # Build amphora image with master DIB in a Python 3 virtual environment
-        (
-            DIB_VENV_DIR=$(mktemp -d)
-            DIB_GIT_DIR=/tmp/dib-octavia
-            python3 -m venv $DIB_VENV_DIR
-            export USE_PYTHON3=True
-            export PATH=$DIB_VENV_DIR/bin:$PATH
-            if ! [ -d $DIB_GIT_DIR ]; then
-                git clone ${GITREPO["diskimage-builder"]} $DIB_GIT_DIR
-            fi
-            (cd $REQUIREMENTS_DIR && git show origin/master:upper-constraints.txt) | sed '/diskimage-builder/d' > $DIB_VENV_DIR/u-c.txt
-            pip install -c $DIB_VENV_DIR/u-c.txt $DIB_GIT_DIR
-            $OCTAVIA_DIR/diskimage-create/diskimage-create.sh -l ${dib_logs}/$(basename $OCTAVIA_AMP_IMAGE_FILE).log $octavia_dib_tracing_arg -o $OCTAVIA_AMP_IMAGE_FILE ${PARAM_OCTAVIA_AMP_BASE_OS:-} ${PARAM_OCTAVIA_AMP_DISTRIBUTION_RELEASE_ID:-} ${PARAM_OCTAVIA_AMP_IMAGE_SIZE:-}
-        )
+        $OCTAVIA_DIR/diskimage-create/diskimage-create.sh -l ${dib_logs}/$(basename $OCTAVIA_AMP_IMAGE_FILE).log $octavia_dib_tracing_arg -o $OCTAVIA_AMP_IMAGE_FILE ${PARAM_OCTAVIA_AMP_BASE_OS:-} ${PARAM_OCTAVIA_AMP_DISTRIBUTION_RELEASE_ID:-} ${PARAM_OCTAVIA_AMP_IMAGE_SIZE:-}
     fi
     upload_image file://${OCTAVIA_AMP_IMAGE_FILE} $TOKEN
 
@@ -200,29 +197,64 @@ function _stop_octavia_apache_wsgi {
 function create_octavia_accounts {
     create_service_user $OCTAVIA
 
-    # Increase the octavia account secgroups quota
+    # Increase the service account secgroups quota
     # This is imporant for concurrent tempest testing
-    openstack quota set --secgroups 100 $OCTAVIA_PROJECT_NAME
-    openstack quota set --secgroup-rules 1000 $OCTAVIA_PROJECT_NAME
+    openstack quota set --secgroups 100 $SERVICE_PROJECT_NAME
 
-    local octavia_service=$(get_or_create_service "octavia" \
+    octavia_service=$(get_or_create_service "octavia" \
         $OCTAVIA_SERVICE_TYPE "Octavia Load Balancing Service")
 
     if [[ "$WSGI_MODE" == "uwsgi" ]] && [[ "$OCTAVIA_NODE" == "main" ]] ; then
         get_or_create_endpoint $octavia_service \
             "$REGION_NAME" \
+            "$OCTAVIA_PROTOCOL://$SERVICE_HOST:$OCTAVIA_PORT/$OCTAVIA_SERVICE_TYPE" \
+            "$OCTAVIA_PROTOCOL://$SERVICE_HOST:$OCTAVIA_PORT/$OCTAVIA_SERVICE_TYPE" \
             "$OCTAVIA_PROTOCOL://$SERVICE_HOST:$OCTAVIA_PORT/$OCTAVIA_SERVICE_TYPE"
     elif [[ "$WSGI_MODE" == "uwsgi" ]]; then
         get_or_create_endpoint $octavia_service \
             "$REGION_NAME" \
+            "$OCTAVIA_PROTOCOL://$SERVICE_HOST/$OCTAVIA_SERVICE_TYPE" \
+            "$OCTAVIA_PROTOCOL://$SERVICE_HOST/$OCTAVIA_SERVICE_TYPE" \
             "$OCTAVIA_PROTOCOL://$SERVICE_HOST/$OCTAVIA_SERVICE_TYPE"
     else
         get_or_create_endpoint $octavia_service \
             "$REGION_NAME" \
+            "$OCTAVIA_PROTOCOL://$SERVICE_HOST:$OCTAVIA_PORT/" \
+            "$OCTAVIA_PROTOCOL://$SERVICE_HOST:$OCTAVIA_PORT/" \
             "$OCTAVIA_PROTOCOL://$SERVICE_HOST:$OCTAVIA_PORT/"
     fi
 }
 
+function install_redis {
+    if is_fedora; then
+        install_package redis
+    elif is_ubuntu; then
+        install_package redis-server
+    elif is_suse; then
+        install_package redis
+    else
+        exit_distro_not_supported "redis installation"
+    fi
+
+    start_service redis
+
+    pip_install_gr redis
+}
+
+function uninstall_redis {
+    if is_fedora; then
+        uninstall_package redis
+    elif is_ubuntu; then
+        uninstall_package redis-server
+    elif is_suse; then
+        uninstall_package redis
+    fi
+
+    stop_service redis
+
+    pip_unistall redis
+}
+
 function octavia_configure {
 
     sudo mkdir -m 755 -p $OCTAVIA_CONF_DIR
@@ -244,13 +276,15 @@ function octavia_configure {
     iniset $OCTAVIA_CONF DEFAULT debug $ENABLE_DEBUG_LOG_LEVEL
 
     # Change bind host
-    iniset $OCTAVIA_CONF api_settings bind_host $SERVICE_HOST
+    iniset $OCTAVIA_CONF api_settings bind_host $(ipv6_unquote $SERVICE_HOST)
     iniset $OCTAVIA_CONF api_settings api_handler queue_producer
 
     iniset $OCTAVIA_CONF database connection "mysql+pymysql://${DATABASE_USER}:${DATABASE_PASSWORD}@${DATABASE_HOST}:3306/octavia"
-
+    if [[ ${OCTAVIA_ENABLE_AMPHORAV2_PROVIDER} == True ]]; then
+        iniset $OCTAVIA_CONF task_flow persistence_connection "mysql+pymysql://${DATABASE_USER}:${DATABASE_PASSWORD}@${DATABASE_HOST}:3306/octavia_persistence"
+    fi
     # Configure keystone auth_token for all users
-    configure_auth_token_middleware $OCTAVIA_CONF octavia
+    configure_keystone_authtoken_middleware $OCTAVIA_CONF octavia
 
     # Ensure config is set up properly for authentication as admin
     iniset $OCTAVIA_CONF service_auth auth_url $OS_AUTH_URL
@@ -322,12 +356,22 @@ function octavia_configure {
     if [ $OCTAVIA_NODE == 'main' ] || [ $OCTAVIA_NODE == 'standalone' ] || [ $OCTAVIA_NODE == 'api' ]; then
         recreate_database_mysql octavia
         octavia-db-manage upgrade head
+
+        if [[ ${OCTAVIA_ENABLE_AMPHORAV2_PROVIDER} == True ]]; then
+            recreate_database_mysql octavia_persistence
+            octavia-db-manage upgrade_persistence
+        fi
     fi
 
     if [[ -a $OCTAVIA_CERTS_DIR ]] ; then
         rm -rf $OCTAVIA_CERTS_DIR
     fi
 
+    # amphorav2 required redis installation
+    if [[ ${OCTAVIA_ENABLE_AMPHORAV2_PROVIDER} == True ]]; then
+        install_redis
+    fi
+
     if [[ "$(trueorfalse False OCTAVIA_USE_PREGENERATED_CERTS)" == "True" ]]; then
         cp -rfp ${OCTAVIA_PREGENERATED_CERTS_DIR} ${OCTAVIA_CERTS_DIR}
     else
@@ -396,7 +440,8 @@ function create_mgmt_network_interface {
     MGMT_PORT_ID=$(openstack port create --security-group lb-health-mgr-sec-grp --device-owner Octavia:health-mgr --host=$(hostname) -c id -f value --network lb-mgmt-net $PORT_FIXED_IP octavia-health-manager-$OCTAVIA_NODE-listen-port)
     MGMT_PORT_MAC=$(openstack port show -c mac_address -f value $MGMT_PORT_ID)
 
-    MGMT_PORT_IP=$(openstack port show -f yaml -c fixed_ips $MGMT_PORT_ID | awk '{FS=",|";gsub(",","");gsub("'\''","");for(line = 1; line <= NF; ++line) {if ($line ~ /^- ip_address:/) {split($line, word, " ");if (ENVIRON["IPV6_ENABLED"] == "" && word[3] ~ /\./) print word[3];if (ENVIRON["IPV6_ENABLED"] != "" && word[3] ~ /:/) print word[3];} else {split($line, word, " ");for(ind in word) {if (word[ind] ~ /^ip_address=/) {split(word[ind], token, "=");if (ENVIRON["IPV6_ENABLED"] == "" && token[2] ~ /\./) print token[2];if (ENVIRON["IPV6_ENABLED"] != "" && token[2] ~ /:/) print token[2];}}}}}')
+    MGMT_PORT_IP=$(openstack port show -f yaml -c fixed_ips $MGMT_PORT_ID | awk -v IP_VER=$SERVICE_IP_VERSION '{FS=",|";gsub(",","");gsub("'\''","");for(line = 1; line <= NF; ++line) {if ($line ~ /^.*- ip_address:/) {split($line, word, " ");if ((IP_VER == "4" || IP_VER == "") && word[3] ~ /\./) print word[3];if (IP_VER == "6" && word[3] ~ /:/) print word[3];} else {split($line, word, " ");for(ind in word) {if (word[ind] ~ /^ip_address=/) {split(word[ind], token, "=");if ((IP_VER == "4" || IP_VER == "") && token[2] ~ /\./) print token[2];if (IP_VER == "6" && token[2] ~ /:/) print token[2];}}}}}')
+
     if function_exists octavia_create_network_interface_device ; then
         octavia_create_network_interface_device o-hm0 $MGMT_PORT_ID $MGMT_PORT_MAC
     elif [[ $NEUTRON_AGENT == "openvswitch" || $Q_AGENT == "openvswitch" ]]; then
@@ -413,16 +458,18 @@ function create_mgmt_network_interface {
         die "Unknown network controller. Please define octavia_create_network_interface_device"
     fi
     sudo ip link set dev o-hm0 address $MGMT_PORT_MAC
-    sudo iptables -I INPUT -i o-hm0 -p udp --dport $OCTAVIA_HM_LISTEN_PORT -j ACCEPT
-    sudo iptables -I INPUT -i o-hm0 -p udp --dport $OCTAVIA_AMP_LOG_ADMIN_PORT -j ACCEPT
-    sudo iptables -I INPUT -i o-hm0 -p udp --dport $OCTAVIA_AMP_LOG_TENANT_PORT -j ACCEPT
-    if [ $IPV6_ENABLED == 'true' ] ; then
+    if [ $SERVICE_IP_VERSION == '6' ] ; then
+        # Allow the required IPv6 ICMP messages
+        sudo ip6tables -I INPUT -i o-hm0 -p ipv6-icmp -j ACCEPT
         sudo ip6tables -I INPUT -i o-hm0 -p udp --dport $OCTAVIA_HM_LISTEN_PORT -j ACCEPT
         sudo ip6tables -I INPUT -i o-hm0 -p udp --dport $OCTAVIA_AMP_LOG_ADMIN_PORT -j ACCEPT
         sudo ip6tables -I INPUT -i o-hm0 -p udp --dport $OCTAVIA_AMP_LOG_TENANT_PORT -j ACCEPT
+    else
+        sudo iptables -I INPUT -i o-hm0 -p udp --dport $OCTAVIA_HM_LISTEN_PORT -j ACCEPT
+        sudo iptables -I INPUT -i o-hm0 -p udp --dport $OCTAVIA_AMP_LOG_ADMIN_PORT -j ACCEPT
+        sudo iptables -I INPUT -i o-hm0 -p udp --dport $OCTAVIA_AMP_LOG_TENANT_PORT -j ACCEPT
     fi
 
-
     if [ $OCTAVIA_CONTROLLER_IP_PORT_LIST == 'auto' ] ; then
         iniset $OCTAVIA_CONF health_manager controller_ip_port_list $MGMT_PORT_IP:$OCTAVIA_HM_LISTEN_PORT
     else
@@ -444,29 +491,37 @@ function create_mgmt_network_interface {
 function build_mgmt_network {
     # Create network and attach a subnet
     openstack network create lb-mgmt-net
-    openstack subnet create --subnet-range $OCTAVIA_MGMT_SUBNET --allocation-pool start=$OCTAVIA_MGMT_SUBNET_START,end=$OCTAVIA_MGMT_SUBNET_END --network lb-mgmt-net lb-mgmt-subnet
-
-    # Create security group and rules
-    openstack security group create lb-mgmt-sec-grp
-    openstack security group rule create --protocol icmp lb-mgmt-sec-grp
-    openstack security group rule create --protocol tcp --dst-port 22 lb-mgmt-sec-grp
-    openstack security group rule create --protocol tcp --dst-port 9443 lb-mgmt-sec-grp
-    if [ $IPV6_ENABLED == 'true' ] ; then
-        openstack security group rule create --protocol icmpv6 --ethertype IPv6 --remote-ip ::/0 lb-mgmt-sec-grp
-        openstack security group rule create --protocol tcp --dst-port 22 --ethertype IPv6 --remote-ip ::/0 lb-mgmt-sec-grp
-        openstack security group rule create --protocol tcp --dst-port 9443 --ethertype IPv6 --remote-ip ::/0 lb-mgmt-sec-grp
+    if [ $SERVICE_IP_VERSION == '6' ] ; then
+        openstack subnet create --subnet-range $OCTAVIA_MGMT_SUBNET_IPV6 --allocation-pool start=$OCTAVIA_MGMT_SUBNET_IPV6_START,end=$OCTAVIA_MGMT_SUBNET_IPV6_END --network lb-mgmt-net --ip-version 6 --ipv6-address-mode slaac --ipv6-ra-mode slaac lb-mgmt-subnet
+    else
+        openstack subnet create --subnet-range $OCTAVIA_MGMT_SUBNET --allocation-pool start=$OCTAVIA_MGMT_SUBNET_START,end=$OCTAVIA_MGMT_SUBNET_END --network lb-mgmt-net lb-mgmt-subnet
     fi
 
     # Create security group and rules
-    openstack security group create lb-health-mgr-sec-grp
-    openstack security group rule create --protocol udp --dst-port $OCTAVIA_HM_LISTEN_PORT lb-health-mgr-sec-grp
-    openstack security group rule create --protocol udp --dst-port $OCTAVIA_AMP_LOG_ADMIN_PORT lb-health-mgr-sec-grp
-    openstack security group rule create --protocol udp --dst-port $OCTAVIA_AMP_LOG_TENANT_PORT lb-health-mgr-sec-grp
+    # Used for the amphora lb-mgmt-net ports
+    openstack security group create lb-mgmt-sec-grp
+    if [ $SERVICE_IP_VERSION == '6' ] ; then
+        openstack security group rule create --protocol ipv6-icmp --ethertype IPv6 --remote-ip ::/0 lb-mgmt-sec-grp
+        openstack security group rule create --protocol tcp --dst-port 22 --ethertype IPv6 --remote-ip ::/0 lb-mgmt-sec-grp
+        openstack security group rule create --protocol tcp --dst-port 9443 --ethertype IPv6 --remote-ip ::/0 lb-mgmt-sec-grp
+    else
+        openstack security group rule create --protocol icmp lb-mgmt-sec-grp
+        openstack security group rule create --protocol tcp --dst-port 22 lb-mgmt-sec-grp
+        openstack security group rule create --protocol tcp --dst-port 9443 lb-mgmt-sec-grp
+    fi
 
-    if [ $IPV6_ENABLED == 'true' ] ; then
+    # Create security group and rules
+    # Used for the health manager port
+    openstack security group create lb-health-mgr-sec-grp
+    if [ $SERVICE_IP_VERSION == '6' ] ; then
+        openstack security group rule create --protocol ipv6-icmp --ethertype IPv6 --remote-ip ::/0 lb-health-mgr-sec-grp
         openstack security group rule create --protocol udp --dst-port $OCTAVIA_HM_LISTEN_PORT --ethertype IPv6 --remote-ip ::/0 lb-health-mgr-sec-grp
         openstack security group rule create --protocol udp --dst-port $OCTAVIA_AMP_LOG_ADMIN_PORT --ethertype IPv6 --remote-ip ::/0 lb-health-mgr-sec-grp
         openstack security group rule create --protocol udp --dst-port $OCTAVIA_AMP_LOG_TENANT_PORT --ethertype IPv6 --remote-ip ::/0 lb-health-mgr-sec-grp
+    else
+        openstack security group rule create --protocol udp --dst-port $OCTAVIA_HM_LISTEN_PORT lb-health-mgr-sec-grp
+        openstack security group rule create --protocol udp --dst-port $OCTAVIA_AMP_LOG_ADMIN_PORT lb-health-mgr-sec-grp
+        openstack security group rule create --protocol udp --dst-port $OCTAVIA_AMP_LOG_TENANT_PORT lb-health-mgr-sec-grp
     fi
 }
 
@@ -493,10 +548,10 @@ function configure_octavia_api_haproxy {
     NODES=(${OCTAVIA_NODES//,/ })
 
     for NODE in ${NODES[@]}; do
-       DATA=(${NODE//:/ })
-       NAME=$(echo -e "${DATA[0]}" | tr -d '[[:space:]]')
-       IP=$(echo -e "${DATA[1]}" | tr -d '[[:space:]]')
-       echo "   server octavia-${NAME} ${IP}:80 weight 1" >> ${OCTAVIA_CONF_DIR}/haproxy.cfg
+        DATA=(${NODE//:/ })
+        NAME=$(echo -e "${DATA[0]}" | tr -d '[[:space:]]')
+        IP=$(echo -e "${DATA[1]}" | tr -d '[[:space:]]')
+        echo "   server octavia-${NAME} ${IP}:80 weight 1" >> ${OCTAVIA_CONF_DIR}/haproxy.cfg
     done
 
 }
@@ -512,7 +567,14 @@ function configure_rsyslog {
 function octavia_start {
 
     if  ! ps aux | grep -q [o]-hm0 && [ $OCTAVIA_NODE != 'api' ] ; then
-        sudo dhclient -v o-hm0 -cf $OCTAVIA_DHCLIENT_CONF
+        if [ $SERVICE_IP_VERSION == '6' ] ; then
+                # This is probably out of scope here? Load it from config
+                MGMT_PORT_IP=$(iniget $OCTAVIA_CONF health_manager bind_ip)
+            sudo ip addr add $MGMT_PORT_IP/64 dev o-hm0
+            sudo ip link set o-hm0 up
+        else
+            sudo dhclient -v o-hm0 -cf $OCTAVIA_DHCLIENT_CONF
+        fi
     fi
 
     if [ $OCTAVIA_NODE == 'main' ]; then
@@ -564,19 +626,19 @@ function octavia_stop {
 function octavia_cleanup {
 
     if [ ${OCTAVIA_AMP_IMAGE_NAME}x != x ] ; then
-         rm -rf ${OCTAVIA_AMP_IMAGE_NAME}*
+        rm -rf ${OCTAVIA_AMP_IMAGE_NAME}*
     fi
     if [ ${OCTAVIA_AMP_SSH_KEY_NAME}x != x ] ; then
-         rm -f  ${OCTAVIA_AMP_SSH_KEY_NAME}*
+        rm -f  ${OCTAVIA_AMP_SSH_KEY_NAME}*
     fi
     if [ ${OCTAVIA_SSH_DIR}x != x ] ; then
-         rm -rf ${OCTAVIA_SSH_DIR}
+        rm -rf ${OCTAVIA_SSH_DIR}
     fi
     if [ ${OCTAVIA_CONF_DIR}x != x ] ; then
-         sudo rm -rf ${OCTAVIA_CONF_DIR}
+        sudo rm -rf ${OCTAVIA_CONF_DIR}
     fi
     if [ ${OCTAVIA_RUN_DIR}x != x ] ; then
-         sudo rm -rf ${OCTAVIA_RUN_DIR}
+        sudo rm -rf ${OCTAVIA_RUN_DIR}
     fi
     if [ ${OCTAVIA_AMP_SSH_KEY_PATH}x != x ] ; then
         rm -f ${OCTAVIA_AMP_SSH_KEY_PATH} ${OCTAVIA_AMP_SSH_KEY_PATH}.pub
@@ -590,8 +652,15 @@ function octavia_cleanup {
         _cleanup_octavia_apache_wsgi
     fi
 
+    sudo rm -rf $OCTAVIA_DIR/bin/dual_ca
+    sudo rm -rf $OCTAVIA_DIR/bin/single_ca
+
     sudo rm -rf $NOVA_STATE_PATH $NOVA_AUTH_CACHE_DIR
 
+    if [[ ${OCTAVIA_ENABLE_AMPHORAV2_PROVIDER} == True ]]; then
+        uninstall_redis
+    fi
+
     sudo rm -f /etc/rsyslog.d/10-octavia-log-offloading.conf
     restart_service rsyslog
 
@@ -607,65 +676,66 @@ function add_load-balancer_roles {
 }
 
 function octavia_init {
-   if [ $OCTAVIA_NODE != 'main' ] && [ $OCTAVIA_NODE != 'standalone' ]  && [ $OCTAVIA_NODE != 'api' ]; then
-       # without the other services enabled apparently we don't have
-       # credentials at this point
-#       TOP_DIR=$(cd $(dirname "$0") && pwd)
-       source ${TOP_DIR}/openrc admin admin
-       OCTAVIA_AMP_NETWORK_ID=$(openstack network show lb-mgmt-net -f value -c id)
-       iniset $OCTAVIA_CONF controller_worker amp_boot_network_list ${OCTAVIA_AMP_NETWORK_ID}
-   fi
+    if [ $OCTAVIA_NODE != 'main' ] && [ $OCTAVIA_NODE != 'standalone' ]  && [ $OCTAVIA_NODE != 'api' ]; then
+        # without the other services enabled apparently we don't have
+        # credentials at this point
+#        TOP_DIR=$(cd $(dirname "$0") && pwd)
+        source ${TOP_DIR}/openrc admin admin
+        OCTAVIA_AMP_NETWORK_ID=$(openstack network show lb-mgmt-net -f value -c id)
+        iniset $OCTAVIA_CONF controller_worker amp_boot_network_list ${OCTAVIA_AMP_NETWORK_ID}
+    fi
 
-   if [ $OCTAVIA_NODE == 'main' ] || [ $OCTAVIA_NODE == 'standalone' ] ; then
-       # things that should only happen on the ha main node / or once
-       if ! openstack keypair show ${OCTAVIA_AMP_SSH_KEY_NAME} ; then
-           openstack keypair create --public-key ${OCTAVIA_AMP_SSH_KEY_PATH}.pub ${OCTAVIA_AMP_SSH_KEY_NAME}
-       fi
+    if [ $OCTAVIA_NODE == 'main' ] || [ $OCTAVIA_NODE == 'standalone' ] ; then
+        # things that should only happen on the ha main node / or once
+        if ! openstack keypair show ${OCTAVIA_AMP_SSH_KEY_NAME} ; then
+            openstack keypair create --public-key ${OCTAVIA_AMP_SSH_KEY_PATH}.pub ${OCTAVIA_AMP_SSH_KEY_NAME}
+        fi
 
-       # Check if an amphora image is already loaded
-       AMPHORA_IMAGE_NAME=$(openstack image list --property name=${OCTAVIA_AMP_IMAGE_NAME} -f value -c Name)
-       export AMPHORA_IMAGE_NAME
+        # Check if an amphora image is already loaded
+        AMPHORA_IMAGE_NAME=$(openstack image list --property name=${OCTAVIA_AMP_IMAGE_NAME} -f value -c Name)
+        export AMPHORA_IMAGE_NAME
 
-       if [ "$AMPHORA_IMAGE_NAME" == ${OCTAVIA_AMP_IMAGE_NAME} ]; then
-           echo "Found existing amphora image: $AMPHORA_IMAGE_NAME"
-           echo "Skipping amphora image build"
-           export DISABLE_AMP_IMAGE_BUILD=True
-       fi
+        if [ "$AMPHORA_IMAGE_NAME" == ${OCTAVIA_AMP_IMAGE_NAME} ]; then
+            echo "Found existing amphora image: $AMPHORA_IMAGE_NAME"
+            echo "Skipping amphora image build"
+            export DISABLE_AMP_IMAGE_BUILD=True
+        fi
 
-       if ! [ "$DISABLE_AMP_IMAGE_BUILD" == 'True' ]; then
-           build_octavia_worker_image
-       fi
+        if ! [ "$DISABLE_AMP_IMAGE_BUILD" == 'True' ]; then
+            build_octavia_worker_image
+        fi
 
-       OCTAVIA_AMP_IMAGE_ID=$(openstack image list -f value --property name=${OCTAVIA_AMP_IMAGE_NAME} -c ID)
+        OCTAVIA_AMP_IMAGE_ID=$(openstack image list -f value --property name=${OCTAVIA_AMP_IMAGE_NAME} -c ID)
 
-       if [ -n "$OCTAVIA_AMP_IMAGE_ID" ]; then
-           openstack image set --tag ${OCTAVIA_AMP_IMAGE_TAG} --property hw_architecture='x86_64' --property hw_rng_model=virtio ${OCTAVIA_AMP_IMAGE_ID}
-       fi
+        if [ -n "$OCTAVIA_AMP_IMAGE_ID" ]; then
+            openstack image set --tag ${OCTAVIA_AMP_IMAGE_TAG} --property hw_architecture='x86_64' --property hw_rng_model=virtio ${OCTAVIA_AMP_IMAGE_ID}
+        fi
 
-       # Create a management network.
-       build_mgmt_network
-       OCTAVIA_AMP_NETWORK_ID=$(openstack network show lb-mgmt-net -f value -c id)
-       iniset $OCTAVIA_CONF controller_worker amp_boot_network_list ${OCTAVIA_AMP_NETWORK_ID}
+        # Create a management network.
+        build_mgmt_network
+        OCTAVIA_AMP_NETWORK_ID=$(openstack network show lb-mgmt-net -f value -c id)
+        iniset $OCTAVIA_CONF controller_worker amp_boot_network_list ${OCTAVIA_AMP_NETWORK_ID}
 
-       create_octavia_accounts
+        create_octavia_accounts
 
-       add_load-balancer_roles
-   elif [ $OCTAVIA_NODE == 'api' ] ; then
-       create_octavia_accounts
+        add_load-balancer_roles
 
-       add_load-balancer_roles
-   fi
+        configure_rsyslog
+    elif [ $OCTAVIA_NODE == 'api' ] ; then
+        create_octavia_accounts
 
-   if [ $OCTAVIA_NODE != 'api' ] ; then
-       create_mgmt_network_interface
-       create_amphora_flavor
-       configure_lb_mgmt_sec_grp
-       configure_rsyslog
-   fi
+        add_load-balancer_roles
+    fi
 
-   if ! [ "$DISABLE_AMP_IMAGE_BUILD" == 'True' ]; then
-       set_octavia_worker_image_owner_id
-   fi
+    if [ $OCTAVIA_NODE != 'api' ] ; then
+        create_mgmt_network_interface
+        create_amphora_flavor
+        configure_lb_mgmt_sec_grp
+    fi
+
+    if ! [ "$DISABLE_AMP_IMAGE_BUILD" == 'True' ]; then
+        set_octavia_worker_image_owner_id
+    fi
 }
 
 function _configure_tempest {
