@@ -24,7 +24,6 @@ import flask
 import jinja2
 from oslo_config import cfg
 from oslo_log import log as logging
-import six
 import webob
 from werkzeug import exceptions
 
@@ -59,8 +58,8 @@ class Wrapped(object):
         self.stream = stream_
         self.hash = hashlib.md5()  # nosec
 
-    def read(self, l):
-        block = self.stream.read(l)
+    def read(self, line):
+        block = self.stream.read(line)
         if block:
             self.hash.update(block)
         return block
@@ -86,7 +85,8 @@ class Loadbalancer(object):
         with open(util.config_path(lb_id), 'r') as file:
             cfg = file.read()
             resp = webob.Response(cfg, content_type='text/plain')
-            resp.headers['ETag'] = hashlib.md5(six.b(cfg)).hexdigest()  # nosec
+            resp.headers['ETag'] = (
+                hashlib.md5(octavia_utils.b(cfg)).hexdigest())  # nosec
             return resp
 
     def upload_haproxy_config(self, amphora_id, lb_id):
@@ -235,11 +235,12 @@ class Loadbalancer(object):
                 details="Unknown action: {0}".format(action)), status=400)
 
         self._check_lb_exists(lb_id)
-        is_vrrp = (CONF.controller_worker.loadbalancer_topology ==
-                   consts.TOPOLOGY_ACTIVE_STANDBY)
 
-        if is_vrrp:
-            util.vrrp_check_script_update(lb_id, action)
+        # Since this script should be created at LB create time
+        # we can check for this path to see if VRRP is enabled
+        # on this amphora and not write the file if VRRP is not in use
+        if os.path.exists(util.keepalived_check_script_path()):
+            self.vrrp_check_script_update(lb_id, action)
 
         # HAProxy does not start the process when given a reload
         # so start it if haproxy is not already running
@@ -261,14 +262,6 @@ class Loadbalancer(object):
                 return webob.Response(json=dict(
                     message="Error {0}ing haproxy".format(action),
                     details=e.output), status=500)
-
-        # If we are not in active/standby we need to send an IP
-        # advertisement (GARP or NA). Keepalived handles this for
-        # active/standby load balancers.
-        if not is_vrrp and action in [consts.AMP_ACTION_START,
-                                      consts.AMP_ACTION_RELOAD]:
-            util.send_vip_advertisements(lb_id)
-
         if action in [consts.AMP_ACTION_STOP,
                       consts.AMP_ACTION_RELOAD]:
             return webob.Response(json=dict(
@@ -314,7 +307,7 @@ class Loadbalancer(object):
         # we can check for this path to see if VRRP is enabled
         # on this amphora and not write the file if VRRP is not in use
         if os.path.exists(util.keepalived_check_script_path()):
-            util.vrrp_check_script_update(
+            self.vrrp_check_script_update(
                 lb_id, action=consts.AMP_ACTION_STOP)
 
         # delete the ssl files
@@ -415,7 +408,7 @@ class Loadbalancer(object):
 
         with open(cert_path, 'r') as crt_file:
             cert = crt_file.read()
-            md5 = hashlib.md5(six.b(cert)).hexdigest()  # nosec
+            md5 = hashlib.md5(octavia_utils.b(cert)).hexdigest()  # nosec
             resp = webob.Response(json=dict(md5sum=md5))
             resp.headers['ETag'] = md5
             return resp
@@ -462,6 +455,22 @@ class Loadbalancer(object):
     def _cert_file_path(self, lb_id, filename):
         return os.path.join(self._cert_dir(lb_id), filename)
 
+    def vrrp_check_script_update(self, lb_id, action):
+        lb_ids = util.get_loadbalancers()
+        if action == consts.AMP_ACTION_STOP:
+            lb_ids.remove(lb_id)
+        args = []
+        for lbid in lb_ids:
+            args.append(util.haproxy_sock_path(lbid))
+
+        if not os.path.exists(util.keepalived_dir()):
+            os.makedirs(util.keepalived_dir())
+            os.makedirs(util.keepalived_check_scripts_dir())
+
+        cmd = 'haproxy-vrrp-check {args}; exit $?'.format(args=' '.join(args))
+        with open(util.haproxy_check_script_path(), 'w') as text_file:
+            text_file.write(cmd)
+
     def _check_haproxy_status(self, lb_id):
         if os.path.exists(util.pid_path(lb_id)):
             if os.path.exists(
