@@ -23,7 +23,6 @@ from oslo_context import context as oslo_context
 from oslo_log import log as logging
 import requests
 import simplejson
-import six
 from stevedore import driver as stevedore_driver
 
 from octavia.amphorae.driver_exceptions import exceptions as driver_except
@@ -91,7 +90,7 @@ class HaproxyAmphoraLoadBalancerDriver(
 
         return haproxy_version_string.split('.')[:2]
 
-    def _populate_amphora_api_version(self, amphora, timeout_dict=None,
+    def _populate_amphora_api_version(self, amphora,
                                       raise_retry_exception=False):
         """Populate the amphora object with the api_version
 
@@ -103,7 +102,7 @@ class HaproxyAmphoraLoadBalancerDriver(
         if not getattr(amphora, 'api_version', None):
             try:
                 amphora.api_version = self.clients['base'].get_api_version(
-                    amphora, timeout_dict=timeout_dict,
+                    amphora,
                     raise_retry_exception=raise_retry_exception)['api_version']
             except exc.NotFound:
                 # Amphora is too old for version discovery, default to 0.5
@@ -204,9 +203,9 @@ class HaproxyAmphoraLoadBalancerDriver(
                     else:
                         listeners_to_update.append(listener)
                 except Exception as e:
-                    LOG.exception('Unable to update listener {0} due to '
-                                  '"{1}". Skipping this listener.'.format(
-                                      listener.id, e))
+                    LOG.error('Unable to update listener {0} due to "{1}". '
+                              'Skipping this listener.'.format(
+                                  listener.id, str(e)))
                     listener_repo = repo.ListenerRepository()
                     listener_repo.update(db_apis.get_session(), listener.id,
                                          provisioning_status=consts.ERROR,
@@ -292,11 +291,8 @@ class HaproxyAmphoraLoadBalancerDriver(
                         getattr(self.clients[amp.api_version], func_name)(
                             amp, loadbalancer.id, *args)
 
-    def reload(self, loadbalancer, amphora=None, timeout_dict=None):
-        self._apply('reload_listener', loadbalancer, amphora, timeout_dict)
-
-    def start(self, loadbalancer, amphora=None, timeout_dict=None):
-        self._apply('start_listener', loadbalancer, amphora, timeout_dict)
+    def start(self, loadbalancer, amphora=None):
+        self._apply('start_listener', loadbalancer, amphora)
 
     def delete(self, listener):
         # Delete any UDP listeners the old way (we didn't update the way they
@@ -356,8 +352,8 @@ class HaproxyAmphoraLoadBalancerDriver(
 
         # See how many non-UDP listeners we have left
         non_udp_listener_count = len([
-            1 for l in listener.load_balancer.listeners
-            if l.protocol != consts.PROTOCOL_UDP])
+            1 for li in listener.load_balancer.listeners
+            if li.protocol != consts.PROTOCOL_UDP])
         if non_udp_listener_count > 0:
             # We have other listeners, so just update is fine.
             # TODO(rm_work): This is a little inefficient since this duplicates
@@ -381,10 +377,14 @@ class HaproxyAmphoraLoadBalancerDriver(
     def finalize_amphora(self, amphora):
         pass
 
-    def post_vip_plug(self, amphora, load_balancer, amphorae_network_config):
+    def post_vip_plug(self, amphora, load_balancer, amphorae_network_config,
+                      vrrp_port=None, vip_subnet=None):
         if amphora.status != consts.DELETED:
             self._populate_amphora_api_version(amphora)
-            subnet = amphorae_network_config.get(amphora.id).vip_subnet
+            if vip_subnet is None:
+                subnet = amphorae_network_config.get(amphora.id).vip_subnet
+            else:
+                subnet = vip_subnet
             # NOTE(blogan): using the vrrp port here because that
             # is what the allowed address pairs network driver sets
             # this particular port to.  This does expose a bit of
@@ -394,8 +394,12 @@ class HaproxyAmphoraLoadBalancerDriver(
             # NOTE (johnsom): I am loading the vrrp_ip into the
             # net_info structure here so that I don't break
             # compatibility with old amphora agent versions.
-
-            port = amphorae_network_config.get(amphora.id).vrrp_port
+            if vrrp_port is None:
+                port = amphorae_network_config.get(amphora.id).vrrp_port
+                mtu = port.network.mtu
+            else:
+                port = vrrp_port
+                mtu = port.network['mtu']
             LOG.debug("Post-VIP-Plugging with vrrp_ip %s vrrp_port %s",
                       amphora.vrrp_ip, port.id)
             host_routes = [{'nexthop': hr.nexthop,
@@ -405,7 +409,7 @@ class HaproxyAmphoraLoadBalancerDriver(
                         'gateway': subnet.gateway_ip,
                         'mac_address': port.mac_address,
                         'vrrp_ip': amphora.vrrp_ip,
-                        'mtu': port.network.mtu,
+                        'mtu': mtu,
                         'host_routes': host_routes}
             try:
                 self.clients[amphora.api_version].plug_vip(
@@ -498,7 +502,8 @@ class HaproxyAmphoraLoadBalancerDriver(
                 amphora, obj_id, pem=secret, md5=md5, name=name)
         return name
 
-    def _process_listener_pool_certs(self, listener, amphora, obj_id):
+    def _process_listener_pool_certs(self, listener, amphora=None,
+                                     obj_id=None):
         #     {'POOL-ID': {
         #         'client_cert': client_full_filename,
         #         'ca_cert': ca_cert_full_filename,
@@ -516,34 +521,33 @@ class HaproxyAmphoraLoadBalancerDriver(
                                              amphora, obj_id))
         return pool_certs_dict
 
-    def _process_pool_certs(self, listener, pool, amphora, obj_id):
+    def _process_pool_certs(self, listener, pool, amphora=None, obj_id=None):
         pool_cert_dict = dict()
 
         # Handle the client cert(s) and key
         if pool.tls_certificate_id:
             data = cert_parser.load_certificates_data(self.cert_manager, pool)
-            tls_cert = data['tls_cert']
-            pem = cert_parser.build_pem(tls_cert)
+            pem = cert_parser.build_pem(data)
             try:
                 pem = pem.encode('utf-8')
             except AttributeError:
                 pass
             md5 = hashlib.md5(pem).hexdigest()  # nosec
-            name = '{id}.pem'.format(id=tls_cert.id)
+            name = '{id}.pem'.format(id=data.id)
             if amphora and obj_id:
                 self._upload_cert(amphora, obj_id, pem=pem, md5=md5, name=name)
             pool_cert_dict['client_cert'] = os.path.join(
-                CONF.haproxy_amphora.base_cert_dir, obj_id, name)
+                CONF.haproxy_amphora.base_cert_dir, listener.id, name)
         if pool.ca_tls_certificate_id:
             name = self._process_secret(listener, pool.ca_tls_certificate_id,
                                         amphora, obj_id)
             pool_cert_dict['ca_cert'] = os.path.join(
-                CONF.haproxy_amphora.base_cert_dir, obj_id, name)
+                CONF.haproxy_amphora.base_cert_dir, listener.id, name)
         if pool.crl_container_id:
             name = self._process_secret(listener, pool.crl_container_id,
                                         amphora, obj_id)
             pool_cert_dict['crl'] = os.path.join(
-                CONF.haproxy_amphora.base_cert_dir, obj_id, name)
+                CONF.haproxy_amphora.base_cert_dir, listener.id, name)
 
         return pool_cert_dict
 
@@ -584,28 +588,6 @@ class HaproxyAmphoraLoadBalancerDriver(
                       'API.'.format(amphora.id))
             raise driver_except.AmpDriverNotImplementedError()
 
-    def get_interface_from_ip(self, amphora, ip_address, timeout_dict=None):
-        """Get the interface name for an IP address.
-
-        :param amphora: The amphora to query.
-        :type amphora: octavia.db.models.Amphora
-        :param ip_address: The IP address to lookup. (IPv4 or IPv6)
-        :type ip_address: string
-        :param timeout_dict: Dictionary of timeout values for calls to the
-                             amphora. May contain: req_conn_timeout,
-                             req_read_timeout, conn_max_retries,
-                             conn_retry_interval
-        :type timeout_dict: dict
-        :returns: None if not found, the interface name string if found.
-        """
-        try:
-            self._populate_amphora_api_version(amphora, timeout_dict)
-            response_json = self.clients[amphora.api_version].get_interface(
-                amphora, ip_address, timeout_dict, log_error=False)
-            return response_json.get('interface', None)
-        except (exc.NotFound, driver_except.TimeOutException):
-            return None
-
 
 # Check a custom hostname
 class CustomHostNameCheckingAdapter(requests.adapters.HTTPAdapter):
@@ -681,7 +663,7 @@ class AmphoraAPIClientBase(object):
         self.ssl_adapter.uuid = amp.id
         exception = None
         # Keep retrying
-        for dummy in six.moves.xrange(conn_max_retries):
+        for dummy in range(conn_max_retries):
             try:
                 with warnings.catch_warnings():
                     warnings.filterwarnings(
@@ -722,9 +704,8 @@ class AmphoraAPIClientBase(object):
                     # For taskflow persistence cause attribute should
                     # be serializable to JSON. Pass None, as cause exception
                     # is described in the expection message.
-                    six.raise_from(
-                        driver_except.AmpConnectionRetry(exception=str(e)),
-                        None)
+                    raise driver_except.AmpConnectionRetry(
+                        exception=str(e)) from None
         LOG.error("Connection retries (currently set to %(max_retries)s) "
                   "exhausted.  The amphora is unavailable. Reason: "
                   "%(exception)s",
@@ -732,10 +713,9 @@ class AmphoraAPIClientBase(object):
                    'exception': exception})
         raise driver_except.TimeOutException()
 
-    def get_api_version(self, amp, timeout_dict=None,
-                        raise_retry_exception=False):
+    def get_api_version(self, amp, raise_retry_exception=False):
         amp.api_version = None
-        r = self.get(amp, retry_404=False, timeout_dict=timeout_dict,
+        r = self.get(amp, retry_404=False,
                      raise_retry_exception=raise_retry_exception)
         # Handle 404 special as we don't want to log an ERROR on 404
         exc.check_exception(r, (404,))
@@ -836,15 +816,16 @@ class AmphoraAPIClient0_5(AmphoraAPIClientBase):
         r = self.put(amp, 'vrrp/upload', data=config)
         return exc.check_exception(r)
 
-    def _vrrp_action(self, action, amp, timeout_dict=None):
-        r = self.put(amp, 'vrrp/{action}'.format(action=action),
-                     timeout_dict=timeout_dict)
+    def _vrrp_action(self, action, amp):
+        r = self.put(amp, 'vrrp/{action}'.format(action=action))
         return exc.check_exception(r)
 
-    def get_interface(self, amp, ip_addr, timeout_dict=None, log_error=True):
+    def get_interface(self, amp, ip_addr, timeout_dict=None):
         r = self.get(amp, 'interface/{ip_addr}'.format(ip_addr=ip_addr),
                      timeout_dict=timeout_dict)
-        return exc.check_exception(r, log_error=log_error).json()
+        if exc.check_exception(r):
+            return r.json()
+        return None
 
     def upload_udp_config(self, amp, listener_id, config, timeout_dict=None):
         r = self.put(
@@ -965,15 +946,16 @@ class AmphoraAPIClient1_0(AmphoraAPIClientBase):
         r = self.put(amp, 'vrrp/upload', data=config)
         return exc.check_exception(r)
 
-    def _vrrp_action(self, action, amp, timeout_dict=None):
-        r = self.put(amp, 'vrrp/{action}'.format(action=action),
-                     timeout_dict=timeout_dict)
+    def _vrrp_action(self, action, amp):
+        r = self.put(amp, 'vrrp/{action}'.format(action=action))
         return exc.check_exception(r)
 
-    def get_interface(self, amp, ip_addr, timeout_dict=None, log_error=True):
+    def get_interface(self, amp, ip_addr, timeout_dict=None):
         r = self.get(amp, 'interface/{ip_addr}'.format(ip_addr=ip_addr),
                      timeout_dict=timeout_dict)
-        return exc.check_exception(r, log_error=log_error).json()
+        if exc.check_exception(r):
+            return r.json()
+        return None
 
     def upload_udp_config(self, amp, listener_id, config, timeout_dict=None):
         r = self.put(
