@@ -49,30 +49,21 @@ class NoopManager(object):
     def update(self, loadbalancer):
         LOG.debug("Amphora %s no-op, update listener %s, vip %s",
                   self.__class__.__name__,
-                  tuple(l.protocol_port for l in loadbalancer.listeners),
+                  tuple(li.protocol_port for li in loadbalancer.listeners),
                   loadbalancer.vip.ip_address)
         self.amphoraconfig[
-            (tuple(l.protocol_port for l in loadbalancer.listeners),
+            (tuple(li.protocol_port for li in loadbalancer.listeners),
              loadbalancer.vip.ip_address)] = (loadbalancer.listeners,
                                               loadbalancer.vip,
                                               'active')
 
-    def start(self, loadbalancer, amphora=None, timeout_dict=None):
-        LOG.debug("Amphora %s no-op, start listeners, lb %s, amp %s"
-                  "timeouts %s", self.__class__.__name__, loadbalancer.id,
-                  amphora, timeout_dict)
+    def start(self, loadbalancer, amphora=None):
+        LOG.debug("Amphora %s no-op, start listeners, lb %s, amp %s",
+                  self.__class__.__name__, loadbalancer.id, amphora)
         self.amphoraconfig[
             (loadbalancer.id, amphora.id)] = (loadbalancer, amphora,
                                               'start')
 
-    def reload(self, loadbalancer, amphora=None, timeout_dict=None):
-        LOG.debug("Amphora %s no-op, reload listeners, lb %s, amp %s, "
-                  "timeouts %s", self.__class__.__name__, loadbalancer.id,
-                  amphora, timeout_dict)
-        self.amphoraconfig[
-            (loadbalancer.id, amphora.id)] = (loadbalancer, amphora,
-                                              'reload')
-
     def delete(self, listener):
         LOG.debug("Amphora %s no-op, delete listener %s, vip %s",
                   self.__class__.__name__,
@@ -103,7 +94,8 @@ class NoopManager(object):
         self.amphoraconfig[amphora.id, port.id] = (amphora.id, port.id,
                                                    'post_network_plug')
 
-    def post_vip_plug(self, amphora, load_balancer, amphorae_network_config):
+    def post_vip_plug(self, amphora, load_balancer, amphorae_network_config,
+                      vrrp_port=None, vip_subnet=None):
         LOG.debug("Amphora %s no-op, post vip plug load balancer %s",
                   self.__class__.__name__, load_balancer.id)
         self.amphoraconfig[(load_balancer.id, id(amphorae_network_config))] = (
@@ -122,13 +114,6 @@ class NoopManager(object):
         self.amphoraconfig[amphora.id, agent_config] = (
             amphora.id, agent_config, 'update_amphora_agent_config')
 
-    def get_interface_from_ip(self, amphora, ip_address, timeout_dict=None):
-        LOG.debug("Amphora %s no-op, get interface from amphora %s for IP %s",
-                  self.__class__.__name__, amphora.id, ip_address)
-        if ip_address == '198.51.100.99':
-            return "noop0"
-        return None
-
 
 class NoopAmphoraLoadBalancerDriver(
     driver_base.AmphoraLoadBalancerDriver,
@@ -146,13 +131,9 @@ class NoopAmphoraLoadBalancerDriver(
 
         self.driver.update(loadbalancer)
 
-    def start(self, loadbalancer, amphora=None, timeout_dict=None):
+    def start(self, loadbalancer, amphora=None):
 
-        self.driver.start(loadbalancer, amphora, timeout_dict)
-
-    def reload(self, loadbalancer, amphora=None, timeout_dict=None):
-
-        self.driver.reload(loadbalancer, amphora, timeout_dict)
+        self.driver.start(loadbalancer, amphora)
 
     def delete(self, listener):
 
@@ -175,10 +156,12 @@ class NoopAmphoraLoadBalancerDriver(
 
         self.driver.post_network_plug(amphora, port)
 
-    def post_vip_plug(self, amphora, load_balancer, amphorae_network_config):
+    def post_vip_plug(self, amphora, load_balancer, amphorae_network_config,
+                      vrrp_port=None, vip_subnet=None):
 
         self.driver.post_vip_plug(amphora,
-                                  load_balancer, amphorae_network_config)
+                                  load_balancer, amphorae_network_config,
+                                  vrrp_port=vrrp_port, vip_subnet=vip_subnet)
 
     def upload_cert_amp(self, amphora, pem_file):
 
@@ -187,19 +170,17 @@ class NoopAmphoraLoadBalancerDriver(
     def update_amphora_agent_config(self, amphora, agent_config):
         self.driver.update_amphora_agent_config(amphora, agent_config)
 
-    def get_interface_from_ip(self, amphora, ip_address, timeout_dict=None):
-        return self.driver.get_interface_from_ip(amphora, ip_address,
-                                                 timeout_dict)
-
-    def update_vrrp_conf(self, loadbalancer, amphorae_network_config, amphora,
-                         timeout_dict=None):
+    def update_vrrp_conf(self, loadbalancer):
         pass
 
     def stop_vrrp_service(self, loadbalancer):
         pass
 
-    def start_vrrp_service(self, amphora, timeout_dict=None):
+    def start_vrrp_service(self, loadbalancer):
         pass
 
     def reload_vrrp_service(self, loadbalancer):
         pass
+
+    def get_vrrp_interface(self, amphora):
+        pass
