@@ -14,8 +14,6 @@
 
 import copy
 
-import six
-
 from octavia_lib.api.drivers import data_models as driver_dm
 from octavia_lib.api.drivers import exceptions as lib_exceptions
 from oslo_config import cfg
@@ -24,8 +22,6 @@ from oslo_log import log as logging
 from oslo_utils import excutils
 from stevedore import driver as stevedore_driver
 
-from octavia.api.drivers import exceptions as driver_exceptions
-from octavia.common import constants
 from octavia.common import data_models
 from octavia.common import exceptions
 from octavia.common.tls_utils import cert_parser
@@ -53,14 +49,12 @@ def call_provider(provider, driver_method, *args, **kwargs):
 
     try:
         return driver_method(*args, **kwargs)
-    except (driver_exceptions.DriverError, lib_exceptions.DriverError) as e:
+    except lib_exceptions.DriverError as e:
         LOG.exception("Provider '%s' raised a driver error: %s",
                       provider, e.operator_fault_string)
         raise exceptions.ProviderDriverError(prov=provider,
                                              user_msg=e.user_fault_string)
-    except (driver_exceptions.NotImplementedError,
-            lib_exceptions.NotImplementedError,
-            NotImplementedError) as e:
+    except (lib_exceptions.NotImplementedError, NotImplementedError) as e:
         op_fault_string = (
             e.operator_fault_string
             if hasattr(e, "operator_fault_string")
@@ -73,8 +67,7 @@ def call_provider(provider, driver_method, *args, **kwargs):
                  provider, op_fault_string)
         raise exceptions.ProviderNotImplementedError(
             prov=provider, user_msg=usr_fault_string)
-    except (driver_exceptions.UnsupportedOptionError,
-            lib_exceptions.UnsupportedOptionError) as e:
+    except lib_exceptions.UnsupportedOptionError as e:
         LOG.info("Provider '%s' raised an unsupported option error: "
                  "%s", provider, e.operator_fault_string)
         raise exceptions.ProviderUnsupportedOptionError(
@@ -174,6 +167,13 @@ def db_listeners_to_provider_listeners(db_listeners, for_delete=False):
     return provider_listeners
 
 
+def db_listeners_to_provider_dicts_list_of_dicts(db_listeners,
+                                                 for_delete=False):
+    listeners = db_listeners_to_provider_listeners(
+        db_listeners, for_delete=for_delete)
+    return [listener.to_dict() for listener in listeners]
+
+
 def db_listener_to_provider_listener(db_listener, for_delete=False):
     new_listener_dict = listener_dict_to_provider_dict(
         db_listener.to_dict(recurse=True), for_delete=for_delete)
@@ -220,6 +220,19 @@ def listener_dict_to_provider_dict(listener_dict, for_delete=False):
     if 'tls_certificate_id' in new_listener_dict:
         new_listener_dict['default_tls_container_ref'] = new_listener_dict.pop(
             'tls_certificate_id')
+    if 'sni_containers' in new_listener_dict:
+        sni_refs = []
+        sni_containers = new_listener_dict.pop('sni_containers')
+        for sni in sni_containers:
+            if 'tls_container_id' in sni:
+                sni_refs.append(sni['tls_container_id'])
+            else:
+                raise exceptions.ValidationException(
+                    detail=_('Invalid SNI container on listener'))
+        new_listener_dict['sni_container_refs'] = sni_refs
+    if 'sni_container_refs' in listener_dict:
+        listener_dict['sni_containers'] = listener_dict.pop(
+            'sni_container_refs')
     if 'client_ca_tls_certificate_id' in new_listener_dict:
         new_listener_dict['client_ca_tls_container_ref'] = (
             new_listener_dict.pop('client_ca_tls_certificate_id'))
@@ -232,9 +245,11 @@ def listener_dict_to_provider_dict(listener_dict, for_delete=False):
         SNI_objs = []
         for sni in listener_obj.sni_containers:
             if isinstance(sni, dict):
+                if 'listener' in sni:
+                    del sni['listener']
                 sni_obj = data_models.SNI(**sni)
                 SNI_objs.append(sni_obj)
-            elif isinstance(sni, six.string_types):
+            elif isinstance(sni, str):
                 sni_obj = data_models.SNI(tls_container_id=sni)
                 SNI_objs.append(sni_obj)
             else:
@@ -282,20 +297,6 @@ def listener_dict_to_provider_dict(listener_dict, for_delete=False):
         new_listener_dict['allowed_cidrs'] = [cidr_dict['cidr'] for
                                               cidr_dict in cidrs_dict_list]
 
-    # Format the sni_containers -> sni_container_refs
-    sni_containers = new_listener_dict.pop('sni_containers', None)
-    if sni_containers:
-        new_listener_dict['sni_container_refs'] = []
-        for sni in sni_containers:
-            if isinstance(sni, dict):
-                new_listener_dict['sni_container_refs'].append(
-                    sni['tls_container_id'])
-            elif isinstance(sni, str):
-                new_listener_dict['sni_container_refs'].append(sni)
-            else:
-                raise exceptions.ValidationException(
-                    detail=_('Invalid SNI container on listener'))
-
     # Remove the DB back references
     if 'load_balancer' in new_listener_dict:
         del new_listener_dict['load_balancer']
@@ -543,9 +544,6 @@ def vip_dict_to_provider_dict(vip_dict):
         new_vip_dict['vip_subnet_id'] = vip_dict['subnet_id']
     if 'qos_policy_id' in vip_dict:
         new_vip_dict['vip_qos_policy_id'] = vip_dict['qos_policy_id']
-    if constants.OCTAVIA_OWNED in vip_dict:
-        new_vip_dict[constants.OCTAVIA_OWNED] = vip_dict[
-            constants.OCTAVIA_OWNED]
     return new_vip_dict
 
 
@@ -561,6 +559,4 @@ def provider_vip_dict_to_vip_obj(vip_dictionary):
         vip_obj.subnet_id = vip_dictionary['vip_subnet_id']
     if 'vip_qos_policy_id' in vip_dictionary:
         vip_obj.qos_policy_id = vip_dictionary['vip_qos_policy_id']
-    if constants.OCTAVIA_OWNED in vip_dictionary:
-        vip_obj.octavia_owned = vip_dictionary[constants.OCTAVIA_OWNED]
     return vip_obj
