@@ -17,7 +17,7 @@ from oslo_config import cfg
 from oslo_db import exception as odb_exceptions
 from oslo_log import log as logging
 from oslo_utils import excutils
-import pecan
+from pecan import request as pecan_request
 from wsme import types as wtypes
 from wsmeext import pecan as wsme_pecan
 
@@ -48,7 +48,7 @@ class HealthMonitorController(base.BaseController):
                          [wtypes.text], ignore_extra_args=True)
     def get_one(self, id, fields=None):
         """Gets a single healthmonitor's details."""
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         db_hm = self._get_db_hm(context.session, id, show_deleted=False)
 
         self._auth_validate_action(context, db_hm.project_id,
@@ -64,7 +64,7 @@ class HealthMonitorController(base.BaseController):
                          [wtypes.text], ignore_extra_args=True)
     def get_all(self, project_id=None, fields=None):
         """Gets all health monitors."""
-        pcontext = pecan.request.context
+        pcontext = pecan_request.context
         context = pcontext.get('octavia_context')
 
         query_filter = self._auth_get_all(context, project_id)
@@ -83,7 +83,7 @@ class HealthMonitorController(base.BaseController):
     def _get_affected_listener_ids(self, session, hm):
         """Gets a list of all listeners this request potentially affects."""
         pool = self.repositories.pool.get(session, id=hm.pool_id)
-        listener_ids = [l.id for l in pool.listeners]
+        listener_ids = [li.id for li in pool.listeners]
         return listener_ids
 
     def _test_lb_and_listener_and_pool_statuses(self, session, hm):
@@ -165,53 +165,47 @@ class HealthMonitorController(base.BaseController):
             raise exceptions.InvalidOption(value='', option='')
 
     def _validate_healthmonitor_request_for_udp(self, request):
-        invalid_fields = (request.http_method or request.url_path or
-                          request.expected_codes)
-        is_invalid = (hasattr(request, 'type') and
-                      (request.type != consts.HEALTH_MONITOR_UDP_CONNECT or
-                       invalid_fields))
-        if is_invalid:
+        if request.type not in (
+                consts.HEALTH_MONITOR_UDP_CONNECT,
+                consts.HEALTH_MONITOR_TCP,
+                consts.HEALTH_MONITOR_HTTP):
             raise exceptions.ValidationException(detail=_(
                 "The associated pool protocol is %(pool_protocol)s, so only "
-                "a %(type)s health monitor is supported.") % {
-                'pool_protocol': consts.PROTOCOL_UDP,
-                'type': consts.HEALTH_MONITOR_UDP_CONNECT})
-        # if the logic arrives here, that means the validation of request above
-        # is OK. type is UDP-CONNECT, then here we check the healthmonitor
-        # delay value is matched.
-        if request.delay:
-            conf_set = (CONF.api_settings.
-                        udp_connect_min_interval_health_monitor)
-            if conf_set < 0:
-                return
-            if request.delay < conf_set:
-                raise exceptions.ValidationException(detail=_(
-                    "The request delay value %(delay)s should be larger than "
-                    "%(conf_set)s for %(type)s health monitor type.") % {
+                "a %(types)s health monitor is supported.") % {
+                    'pool_protocol': consts.PROTOCOL_UDP,
+                    'types': '/'.join((consts.HEALTH_MONITOR_UDP_CONNECT,
+                                       consts.HEALTH_MONITOR_TCP,
+                                       consts.HEALTH_MONITOR_HTTP))})
+        # check the delay value if the HM type is UDP-CONNECT
+        hm_is_type_udp = (
+            request.type == consts.HEALTH_MONITOR_UDP_CONNECT)
+        conf_min_delay = (
+            CONF.api_settings.udp_connect_min_interval_health_monitor)
+        if hm_is_type_udp and request.delay < conf_min_delay:
+            raise exceptions.ValidationException(detail=_(
+                "The request delay value %(delay)s should be larger than "
+                "%(conf_min_delay)s for %(type)s health monitor type.") % {
                     'delay': request.delay,
-                    'conf_set': conf_set,
+                    'conf_min_delay': conf_min_delay,
                     'type': consts.HEALTH_MONITOR_UDP_CONNECT})
 
     @wsme_pecan.wsexpose(hm_types.HealthMonitorRootResponse,
                          body=hm_types.HealthMonitorRootPOST, status_code=201)
     def post(self, health_monitor_):
         """Creates a health monitor on a pool."""
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         health_monitor = health_monitor_.healthmonitor
 
-        pool = self._get_db_pool(context.session, health_monitor.pool_id)
-
-        health_monitor.project_id, provider = self._get_lb_project_id_provider(
-            context.session, pool.load_balancer_id)
-
-        self._auth_validate_action(context, health_monitor.project_id,
-                                   consts.RBAC_POST)
-
         if (not CONF.api_settings.allow_ping_health_monitors and
                 health_monitor.type == consts.HEALTH_MONITOR_PING):
             raise exceptions.DisabledOption(
                 option='type', value=consts.HEALTH_MONITOR_PING)
 
+        pool = self._get_db_pool(context.session, health_monitor.pool_id)
+
+        health_monitor.project_id, provider = self._get_lb_project_id_provider(
+            context.session, pool.load_balancer_id)
+
         if pool.protocol == consts.PROTOCOL_UDP:
             self._validate_healthmonitor_request_for_udp(health_monitor)
         else:
@@ -221,6 +215,9 @@ class HealthMonitorController(base.BaseController):
                     "%(protocol)s.") % {'type': health_monitor.type,
                                         'protocol': consts.PROTOCOL_UDP})
 
+        self._auth_validate_action(context, health_monitor.project_id,
+                                   consts.RBAC_POST)
+
         # Load the driver early as it also provides validation
         driver = driver_factory.get_driver(provider)
 
@@ -334,7 +331,7 @@ class HealthMonitorController(base.BaseController):
                          body=hm_types.HealthMonitorRootPUT, status_code=200)
     def put(self, id, health_monitor_):
         """Updates a health monitor."""
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         health_monitor = health_monitor_.healthmonitor
         db_hm = self._get_db_hm(context.session, id, show_deleted=False)
 
@@ -348,6 +345,7 @@ class HealthMonitorController(base.BaseController):
         # Validate health monitor update options for UDP-CONNECT type.
         if (pool.protocol == consts.PROTOCOL_UDP and
                 db_hm.type == consts.HEALTH_MONITOR_UDP_CONNECT):
+            health_monitor.type = db_hm.type
             self._validate_healthmonitor_request_for_udp(health_monitor)
 
         self._set_default_on_none(health_monitor)
@@ -393,7 +391,7 @@ class HealthMonitorController(base.BaseController):
     @wsme_pecan.wsexpose(None, wtypes.text, status_code=204)
     def delete(self, id):
         """Deletes a health monitor."""
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         db_hm = self._get_db_hm(context.session, id, show_deleted=False)
 
         pool = self._get_db_pool(context.session, db_hm.pool_id)
