@@ -17,7 +17,8 @@ from oslo_config import cfg
 from oslo_db import exception as odb_exceptions
 from oslo_log import log as logging
 from oslo_utils import excutils
-import pecan
+from pecan import expose as pecan_expose
+from pecan import request as pecan_request
 from wsme import types as wtypes
 from wsmeext import pecan as wsme_pecan
 
@@ -51,7 +52,7 @@ class PoolsController(base.BaseController):
                          [wtypes.text], ignore_extra_args=True)
     def get(self, id, fields=None):
         """Gets a pool's details."""
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         db_pool = self._get_db_pool(context.session, id, show_deleted=False)
 
         self._auth_validate_action(context, db_pool.project_id,
@@ -66,7 +67,7 @@ class PoolsController(base.BaseController):
                          [wtypes.text], ignore_extra_args=True)
     def get_all(self, project_id=None, fields=None):
         """Lists all pools."""
-        pcontext = pecan.request.context
+        pcontext = pecan_request.context
         context = pcontext.get('octavia_context')
 
         query_filter = self._auth_get_all(context, project_id)
@@ -82,7 +83,7 @@ class PoolsController(base.BaseController):
 
     def _get_affected_listener_ids(self, pool):
         """Gets a list of all listeners this request potentially affects."""
-        listener_ids = [l.id for l in pool.listeners]
+        listener_ids = [li.id for li in pool.listeners]
         return listener_ids
 
     def _test_lb_and_listener_statuses(self, session, lb_id, listener_ids):
@@ -136,7 +137,7 @@ class PoolsController(base.BaseController):
     def _is_only_specified_in_request(self, request, **kwargs):
         request_attrs = []
         check_attrs = kwargs['check_exist_attrs']
-        escaped_attrs = ['from_data_model', 'translate_key_to_data_model',
+        escaped_attrs = ['from_data_model',
                          'translate_dict_keys_to_data_model', 'to_dict']
 
         for attr in dir(request):
@@ -188,14 +189,23 @@ class PoolsController(base.BaseController):
         # For some API requests the listener_id will be passed in the
         # pool_dict:
         pool = pool_.pool
-        context = pecan.request.context.get('octavia_context')
-        listener = None
+        context = pecan_request.context.get('octavia_context')
+        if pool.protocol == constants.PROTOCOL_UDP:
+            self._validate_pool_request_for_udp(pool)
+        else:
+            if (pool.session_persistence and (
+                    pool.session_persistence.persistence_timeout or
+                    pool.session_persistence.persistence_granularity)):
+                raise exceptions.ValidationException(detail=_(
+                    "persistence_timeout and persistence_granularity "
+                    "is only for UDP protocol pools."))
         if pool.loadbalancer_id:
             pool.project_id, provider = self._get_lb_project_id_provider(
                 context.session, pool.loadbalancer_id)
         elif pool.listener_id:
             listener = self.repositories.listener.get(
                 context.session, id=pool.listener_id)
+            self._validate_protocol(listener.protocol, pool.protocol)
             pool.loadbalancer_id = listener.load_balancer_id
             pool.project_id, provider = self._get_lb_project_id_provider(
                 context.session, pool.loadbalancer_id)
@@ -207,19 +217,6 @@ class PoolsController(base.BaseController):
         self._auth_validate_action(context, pool.project_id,
                                    constants.RBAC_POST)
 
-        if pool.listener_id and listener:
-            self._validate_protocol(listener.protocol, pool.protocol)
-
-        if pool.protocol == constants.PROTOCOL_UDP:
-            self._validate_pool_request_for_udp(pool)
-        else:
-            if (pool.session_persistence and (
-                    pool.session_persistence.persistence_timeout or
-                    pool.session_persistence.persistence_granularity)):
-                raise exceptions.ValidationException(detail=_(
-                    "persistence_timeout and persistence_granularity "
-                    "is only for UDP protocol pools."))
-
         if pool.session_persistence:
             sp_dict = pool.session_persistence.to_dict(render_unsets=False)
             validate.check_session_persistence(sp_dict)
@@ -290,12 +287,21 @@ class PoolsController(base.BaseController):
                 resource=data_models.HealthMonitor._name())
 
         # Now possibly create a healthmonitor
-        new_hm = None
         if hm:
-            hm['pool_id'] = db_pool.id
-            hm['project_id'] = db_pool.project_id
+            hm[constants.POOL_ID] = db_pool.id
+            hm[constants.PROJECT_ID] = db_pool.project_id
             new_hm = health_monitor.HealthMonitorController()._graph_create(
                 lock_session, hm)
+            if db_pool.protocol == constants.PROTOCOL_UDP:
+                health_monitor.HealthMonitorController(
+                )._validate_healthmonitor_request_for_udp(new_hm)
+            else:
+                if new_hm.type == constants.HEALTH_MONITOR_UDP_CONNECT:
+                    raise exceptions.ValidationException(detail=_(
+                        "The %(type)s type is only supported for pools of "
+                        "type %(protocol)s.") % {
+                            'type': new_hm.type,
+                            'protocol': constants.PROTOCOL_UDP})
             db_pool.health_monitor = new_hm
 
         # Now check quotas for members
@@ -376,7 +382,7 @@ class PoolsController(base.BaseController):
     def put(self, id, pool_):
         """Updates a pool on a load balancer."""
         pool = pool_.pool
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         db_pool = self._get_db_pool(context.session, id, show_deleted=False)
 
         project_id, provider = self._get_lb_project_id_provider(
@@ -433,18 +439,17 @@ class PoolsController(base.BaseController):
     @wsme_pecan.wsexpose(None, wtypes.text, status_code=204)
     def delete(self, id):
         """Deletes a pool from a load balancer."""
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         db_pool = self._get_db_pool(context.session, id, show_deleted=False)
+        if db_pool.l7policies:
+            raise exceptions.PoolInUseByL7Policy(
+                id=db_pool.id, l7policy_id=db_pool.l7policies[0].id)
 
         project_id, provider = self._get_lb_project_id_provider(
             context.session, db_pool.load_balancer_id)
 
         self._auth_validate_action(context, project_id, constants.RBAC_DELETE)
 
-        if db_pool.l7policies:
-            raise exceptions.PoolInUseByL7Policy(
-                id=db_pool.id, l7policy_id=db_pool.l7policies[0].id)
-
         # Load the driver early as it also provides validation
         driver = driver_factory.get_driver(provider)
 
@@ -463,14 +468,14 @@ class PoolsController(base.BaseController):
             driver_utils.call_provider(driver.name, driver.pool_delete,
                                        provider_pool)
 
-    @pecan.expose()
+    @pecan_expose()
     def _lookup(self, pool_id, *remainder):
         """Overridden pecan _lookup method for custom routing.
 
         Verifies that the pool passed in the url exists, and if so decides
         which controller, if any, should control be passed.
         """
-        context = pecan.request.context.get('octavia_context')
+        context = pecan_request.context.get('octavia_context')
         if pool_id and remainder and remainder[0] == 'members':
             remainder = remainder[1:]
             db_pool = self.repositories.pool.get(context.session, id=pool_id)
