@@ -10,9 +10,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from cinderclient import client as cinder_client
 from glanceclient import client as glance_client
-from keystoneauth1.identity.generic import token
-from keystoneauth1 import session
 from neutronclient.neutron import client as neutron_client
 from novaclient import api_versions
 from novaclient import client as nova_client
@@ -28,6 +27,7 @@ CONF = cfg.CONF
 GLANCE_VERSION = '2'
 NEUTRON_VERSION = '2.0'
 NOVA_VERSION = '2.15'
+CINDER_VERSION = '3'
 
 
 class NovaAuth(object):
@@ -109,28 +109,27 @@ class NeutronAuth(object):
 
     @classmethod
     def get_user_neutron_client(cls, context):
-        # get a normal session
-        ksession = keystone.KeystoneSession()
-        service_auth = ksession.get_auth()
+        """Get neutron client for request user.
 
-        # make user auth and swap it in session
-        user_auth = token.Token(auth_url=service_auth.auth_url,
-                                token=context.auth_token,
-                                project_id=context.project_id)
-        user_session = session.Session(auth=user_auth)
+        It's possible that the token in the context is a trust scoped
+        which can't be used to initialize a keystone session.
+
+        We directly use the token and endpoint_url to initialize neutron
+        client.
+        """
+        neutron_endpoint = CONF.neutron.endpoint
+        if not neutron_endpoint:
+            session = keystone.KeystoneSession().get_session()
+            endpoint_data = session.get_endpoint_data(service_type='network')
+            neutron_endpoint = endpoint_data.catalog_url
 
         kwargs = {
-            'session': user_session,
-            'region_name': CONF.neutron.region_name,
-            'endpoint_type': CONF.neutron.endpoint_type,
-            'service_name': CONF.neutron.service_name,
+            'token': context.auth_token,
+            'endpoint_url': neutron_endpoint,
             'insecure': CONF.neutron.insecure,
             'ca_cert': CONF.neutron.ca_certificates_file
         }
-        if CONF.neutron.endpoint:
-            kwargs['endpoint_override'] = CONF.neutron.endpoint
 
-        # create neutron client using user's session
         return neutron_client.Client(NEUTRON_VERSION, **kwargs)
 
 
@@ -171,3 +170,43 @@ class GlanceAuth(object):
                 with excutils.save_and_reraise_exception():
                     LOG.exception("Error creating Glance client.")
         return cls.glance_client
+
+
+class CinderAuth(object):
+    cinder_client = None
+
+    @classmethod
+    def get_cinder_client(cls, region, service_name=None, endpoint=None,
+                          endpoint_type='publicURL', insecure=False,
+                          cacert=None):
+        """Create cinder client object.
+
+        :param region: The region of the service
+        :param service_name: The name of the cinder service in the catalog
+        :param endpoint: The endpoint of the service
+        :param endpoint_type: The endpoint type of the service
+        :param insecure: Turn off certificate validation
+        :param cacert: CA Cert file path
+        :return: a Cinder Client object
+        :raise Exception: if the client cannot be created
+        """
+        ksession = keystone.KeystoneSession()
+        if not cls.cinder_client:
+            kwargs = {'region_name': region,
+                      'session': ksession.get_session(),
+                      'interface': endpoint_type}
+            if service_name:
+                kwargs['service_name'] = service_name
+            if endpoint:
+                kwargs['endpoint'] = endpoint
+                if endpoint.startswith("https"):
+                    kwargs['insecure'] = insecure
+                    kwargs['cacert'] = cacert
+            try:
+                cls.cinder_client = cinder_client.Client(
+                    CINDER_VERSION, **kwargs
+                )
+            except Exception:
+                with excutils.save_and_reraise_exception():
+                    LOG.exception("Error creating Cinder client.")
+        return cls.cinder_client
