@@ -36,12 +36,16 @@ from octavia import version
 
 LOG = logging.getLogger(__name__)
 
+EXTRA_LOG_LEVEL_DEFAULTS = [
+    'neutronclient.v2_0.client=INFO',
+]
+
 TLS_PROTOCOL_CHOICES = [
     p[9:].replace('_', '.') for p in ssl._PROTOCOL_NAMES.values()]
 
-
 core_opts = [
     cfg.HostnameOpt('host', default=utils.get_hostname(),
+                    sample_default='<server-hostname.example.com>',
                     help=_("The hostname Octavia is running on")),
     cfg.StrOpt('octavia_plugins', default='hot_plug_plugin',
                help=_("Name of the controller plugin to use")),
@@ -88,7 +92,8 @@ api_opts = [
                        'Amphora driver.'),
                 default={'amphora': 'The Octavia Amphora driver.',
                          'octavia': 'Deprecated alias of the Octavia Amphora '
-                         'driver.'}),
+                         'driver.',
+                         }),
     cfg.StrOpt('default_provider_driver', default='amphora',
                help=_('Default provider driver.')),
     cfg.IntOpt('udp_connect_min_interval_health_monitor',
@@ -96,6 +101,17 @@ api_opts = [
                help=_("The minimum health monitor delay interval for the "
                       "UDP-CONNECT Health Monitor type. A negative integer "
                       "value means 'no limit'.")),
+    cfg.BoolOpt('healthcheck_enabled', default=False,
+                help=_("When True, the oslo middleware healthcheck endpoint "
+                       "is enabled in the Octavia API.")),
+    cfg.StrOpt('default_listener_ciphers',
+               default=constants.CIPHERS_OWASP_SUITE_B,
+               help=_("Default OpenSSL cipher string (colon-separated) for "
+                      "new TLS-enabled listeners.")),
+    cfg.StrOpt('default_pool_ciphers',
+               default=constants.CIPHERS_OWASP_SUITE_B,
+               help=_("Default OpenSSL cipher string (colon-separated) for "
+                      "new TLS-enabled pools.")),
 ]
 
 # Options only used by the amphora agent
@@ -103,7 +119,7 @@ amphora_agent_opts = [
     cfg.StrOpt('agent_server_ca', default='/etc/octavia/certs/client_ca.pem',
                help=_("The ca which signed the client certificates")),
     cfg.StrOpt('agent_server_cert', default='/etc/octavia/certs/server.pem',
-               help=_("The server certificate for the agent.py server "
+               help=_("The server certificate for the agent server "
                       "to use")),
     cfg.StrOpt('agent_server_network_dir',
                help=_("The directory where new network interfaces "
@@ -170,20 +186,6 @@ amphora_agent_opts = [
                help='The UDP API backend for amphora agent.'),
 ]
 
-compute_opts = [
-    cfg.IntOpt('max_retries', default=15,
-               help=_('The maximum attempts to retry an action with the '
-                      'compute service.')),
-    cfg.IntOpt('retry_interval', default=1,
-               help=_('Seconds to wait before retrying an action with the '
-                      'compute service.')),
-    cfg.IntOpt('retry_backoff', default=1,
-               help=_('The seconds to backoff retry attempts.')),
-    cfg.IntOpt('retry_max', default=10,
-               help=_('The maximum interval in seconds between retry '
-                      'attempts.')),
-]
-
 networking_opts = [
     cfg.IntOpt('max_retries', default=15,
                help=_('The maximum attempts to retry an action with the '
@@ -191,11 +193,6 @@ networking_opts = [
     cfg.IntOpt('retry_interval', default=1,
                help=_('Seconds to wait before retrying an action with the '
                       'networking service.')),
-    cfg.IntOpt('retry_backoff', default=1,
-               help=_('The seconds to backoff retry attempts.')),
-    cfg.IntOpt('retry_max', default=10,
-               help=_('The maximum interval in seconds between retry '
-                      'attempts.')),
     cfg.IntOpt('port_detach_timeout', default=300,
                help=_('Seconds to wait for a port to detach from an '
                       'amphora.')),
@@ -308,14 +305,6 @@ haproxy_amphora_opts = [
                default=2,
                help=_('Retry timeout between connection attempts in '
                       'seconds for active amphora.')),
-    cfg.IntOpt('failover_connection_max_retries',
-               default=2,
-               help=_('Retry threshold for connecting to an amphora in '
-                      'failover.')),
-    cfg.IntOpt('failover_connection_retry_interval',
-               default=5,
-               help=_('Retry timeout between connection attempts in '
-                      'seconds for amphora in failover.')),
     cfg.IntOpt('build_rate_limit',
                default=-1,
                help=_('Number of amphorae that could be built per controller '
@@ -332,9 +321,8 @@ haproxy_amphora_opts = [
                help=_('Size of the HAProxy stick table. Accepts k, m, g '
                       'suffixes.  Example: 10k')),
     cfg.StrOpt('user_log_format',
-               default='{{ project_id }} {{ lb_id }} %f %ci %cp %t %{+Q}r %ST '
-                       '%B %U %[ssl_c_verify] %{+Q}[ssl_c_s_dn] %b %s %Tt '
-                       '%tsc',
+               default='{project_id} {lb_id} %f %ci %cp %t %{+Q}r %ST %B %U '
+                       '%[ssl_c_verify] %{+Q}[ssl_c_s_dn] %b %s %Tt %tsc',
                help=_('Log format string for user flow logging.')),
 
     # REST server
@@ -380,21 +368,6 @@ haproxy_amphora_opts = [
                 deprecated_reason='This is now automatically discovered '
                                   ' and configured.',
                 help=_("If False, use sysvinit.")),
-    cfg.IntOpt('api_db_commit_retry_attempts', default=15,
-               help=_('The number of times the database action will be '
-                      'attempted.')),
-    cfg.IntOpt('api_db_commit_retry_initial_delay', default=1,
-               help=_('The initial delay before a retry attempt.')),
-    cfg.IntOpt('api_db_commit_retry_backoff', default=1,
-               help=_('The time to backoff retry attempts.')),
-    cfg.IntOpt('api_db_commit_retry_max', default=5,
-               help=_('The maximum amount of time to wait between retry '
-                      'attempts.')),
-    cfg.IntOpt('default_connection_limit',
-               default=constants.HAPROXY_DEFAULT_MAXCONN,
-               help=_('Default connection_limit for listeners, used when '
-                      'setting "-1" or when unsetting connection_limit with '
-                      'the listener API.')),
 ]
 
 controller_worker_opts = [
@@ -477,11 +450,7 @@ controller_worker_opts = [
                 help=_('If True, build cloud-init user-data that is passed '
                        'to the config drive on Amphora boot instead of '
                        'personality files. If False, utilize personality '
-                       'files.')),
-    cfg.IntOpt('amphora_delete_retries', default=5,
-               help=_('Number of times an amphora delete should be retried.')),
-    cfg.IntOpt('amphora_delete_retry_interval', default=5,
-               help=_('Time, in seconds, between amphora delete retries.')),
+                       'files.'))
 ]
 
 task_flow_opts = [
@@ -499,7 +468,46 @@ task_flow_opts = [
                 help=_('If True, disables the controller worker taskflow '
                        'flows from reverting.  This will leave resources in '
                        'an inconsistent state and should only be used for '
-                       'debugging purposes.'))
+                       'debugging purposes.')),
+    cfg.StrOpt('persistence_connection',
+               default='sqlite://',
+               help='Persistence database, which will be used to store tasks '
+                    'states. Database connection url with db name'),
+    cfg.StrOpt('jobboard_backend_driver',
+               default='redis_taskflow_driver',
+               choices=['redis_taskflow_driver', 'zookeeper_taskflow_driver'],
+               help='Jobboard backend driver that will monitor job state.'),
+    cfg.ListOpt('jobboard_backend_hosts', default=['127.0.0.1'],
+                help='Jobboard backend server host(s).'),
+    cfg.PortOpt('jobboard_backend_port', default=6379,
+                help='Jobboard backend server port'),
+    cfg.StrOpt('jobboard_backend_password', default='', secret=True,
+               help='Jobboard backend server password'),
+    cfg.StrOpt('jobboard_backend_namespace', default='octavia_jobboard',
+               help='Jobboard name that should be used to store taskflow '
+                    'job id and claims for it.'),
+    cfg.DictOpt('jobboard_redis_backend_ssl_options',
+                help='Redis jobboard backend ssl configuration options.',
+                default={'ssl': False,
+                         'ssl_keyfile': None,
+                         'ssl_certfile': None,
+                         'ssl_ca_certs': None,
+                         'ssl_cert_reqs': 'required'}),
+    cfg.DictOpt('jobboard_zookeeper_ssl_options',
+                help='Zookeeper jobboard backend ssl configuration options.',
+                default={'use_ssl': False,
+                         'keyfile': None,
+                         'keyfile_password': None,
+                         'certfile': None,
+                         'verify_certs': True}),
+    cfg.IntOpt('jobboard_expiration_time', default=30,
+               help='For backends like redis claiming jobs requiring setting '
+                    'the expiry - how many seconds the claim should be '
+                    'retained for.'),
+    cfg.BoolOpt('jobboard_save_logbook', default=False,
+                help='If for analysis required saving logbooks info, set this '
+                     'parameter to True. By default remove logbook from '
+                     'persistence backend when job completed.'),
 ]
 
 core_cli_opts = []
@@ -526,8 +534,7 @@ certificate_opts = [
                default='publicURL',
                help='The endpoint_type to be used for barbican service.'),
     cfg.StrOpt('ca_certificates_file',
-               help=_('CA certificates file path for the key manager service '
-                      '(such as Barbican).')),
+               help=_('CA certificates file path')),
     cfg.BoolOpt('insecure',
                 default=False,
                 help=_('Disable certificate validation on SSL connections ')),
@@ -606,8 +613,7 @@ nova_opts = [
                 help=_('Disable certificate validation on SSL connections')),
     cfg.BoolOpt('enable_anti_affinity', default=False,
                 help=_('Flag to indicate if nova anti-affinity feature is '
-                       'turned on. This option is only used when creating '
-                       'amphorae in ACTIVE_STANDBY topology.')),
+                       'turned on.')),
     cfg.StrOpt('anti_affinity_policy', default=constants.ANTI_AFFINITY,
                choices=[constants.ANTI_AFFINITY, constants.SOFT_ANTI_AFFINITY],
                help=_('Sets the anti-affinity policy for nova')),
@@ -643,7 +649,7 @@ cinder_opts = [
     cfg.StrOpt('volume_type', default=None,
                help=_('Type of volume for Amphorae volume root disk')),
     cfg.IntOpt('volume_create_retry_interval', default=5,
-               help=_('Interval time to wait volume is created in available'
+               help=_('Interval time to wait volume is created in available '
                       'state')),
     cfg.IntOpt('volume_create_timeout', default=300,
                help=_('Timeout to wait for volume creation success')),
@@ -772,7 +778,6 @@ driver_agent_opts = [
 cfg.CONF.register_opts(core_opts)
 cfg.CONF.register_opts(api_opts, group='api_settings')
 cfg.CONF.register_opts(amphora_agent_opts, group='amphora_agent')
-cfg.CONF.register_opts(compute_opts, group='compute')
 cfg.CONF.register_opts(networking_opts, group='networking')
 cfg.CONF.register_opts(oslo_messaging_opts, group='oslo_messaging')
 cfg.CONF.register_opts(haproxy_amphora_opts, group='haproxy_amphora')
@@ -780,9 +785,8 @@ cfg.CONF.register_opts(controller_worker_opts, group='controller_worker')
 cfg.CONF.register_opts(keepalived_vrrp_opts, group='keepalived_vrrp')
 cfg.CONF.register_opts(task_flow_opts, group='task_flow')
 cfg.CONF.register_opts(house_keeping_opts, group='house_keeping')
-cfg.CONF.register_cli_opts(core_cli_opts)
 cfg.CONF.register_opts(certificate_opts, group='certificates')
-cfg.CONF.register_cli_opts(healthmanager_opts, group='health_manager')
+cfg.CONF.register_opts(healthmanager_opts, group='health_manager')
 cfg.CONF.register_opts(nova_opts, group='nova')
 cfg.CONF.register_opts(cinder_opts, group='cinder')
 cfg.CONF.register_opts(glance_opts, group='glance')
@@ -802,13 +806,17 @@ _SQL_CONNECTION_DEFAULT = 'sqlite://'
 db_options.set_defaults(cfg.CONF, connection=_SQL_CONNECTION_DEFAULT,
                         max_pool_size=10, max_overflow=20, pool_timeout=10)
 
-logging.register_options(cfg.CONF)
-
 ks_loading.register_auth_conf_options(cfg.CONF, constants.SERVICE_AUTH)
 ks_loading.register_session_conf_options(cfg.CONF, constants.SERVICE_AUTH)
 
 
+def register_cli_opts():
+    cfg.CONF.register_cli_opts(core_cli_opts)
+    logging.register_options(cfg.CONF)
+
+
 def init(args, **kwargs):
+    register_cli_opts()
     cfg.CONF(args=args, project='octavia',
              version='%%prog %s' % version.version_info.release_string(),
              **kwargs)
@@ -821,6 +829,8 @@ def setup_logging(conf):
 
     :param conf: a cfg.ConfOpts object
     """
+    logging.set_defaults(default_log_levels=logging.get_default_log_levels() +
+                         EXTRA_LOG_LEVEL_DEFAULTS)
     product_name = "octavia"
     logging.setup(conf, product_name)
     LOG.info("Logging enabled!")
