@@ -19,7 +19,6 @@ from oslo_db import exception as odb_exceptions
 from oslo_log import log as logging
 from oslo_utils import excutils
 from oslo_utils import uuidutils
-import six
 import sqlalchemy
 from sqlalchemy.orm import exc
 from taskflow import task
@@ -89,13 +88,12 @@ class BaseDatabaseTask(task.Task):
 class CreateAmphoraInDB(BaseDatabaseTask):
     """Task to create an initial amphora in the Database."""
 
-    def execute(self, *args, **kwargs):
+    def execute(self, *args, loadbalancer_id=None, **kwargs):
         """Creates an pending create amphora record in the database.
 
         :returns: The created amphora object
         """
 
-        loadbalancer_id = kwargs.get("loadbalancer_id", None)
         amphora = self.amphora_repo.create(db_apis.get_session(),
                                            id=uuidutils.generate_uuid(),
                                            load_balancer_id=loadbalancer_id,
@@ -451,21 +449,20 @@ class UpdateAmphoraVIPData(BaseDatabaseTask):
 class UpdateAmpFailoverDetails(BaseDatabaseTask):
     """Update amphora failover details in the database."""
 
-    def execute(self, amphora, vip, base_port):
+    def execute(self, amphora, amp_data):
         """Update amphora failover details in the database.
 
         :param amphora: The amphora to update
-        :param vip: The VIP object associated with this amphora.
-        :param base_port: The base port object associated with the amphora.
+        :param amp_data: data_models.Amphora object with update data
         :returns: None
         """
         # role and vrrp_priority will be updated later.
         self.repos.amphora.update(db_apis.get_session(), amphora.id,
-                                  vrrp_ip=base_port.fixed_ips[0].ip_address,
-                                  ha_ip=vip.ip_address,
-                                  vrrp_port_id=base_port.id,
-                                  ha_port_id=vip.port_id,
-                                  vrrp_id=1)
+                                  vrrp_ip=amp_data.vrrp_ip,
+                                  ha_ip=amp_data.ha_ip,
+                                  vrrp_port_id=amp_data.vrrp_port_id,
+                                  ha_port_id=amp_data.ha_port_id,
+                                  vrrp_id=amp_data.vrrp_id)
 
 
 class AssociateFailoverAmphoraWithLBID(BaseDatabaseTask):
@@ -502,7 +499,8 @@ class AssociateFailoverAmphoraWithLBID(BaseDatabaseTask):
 class MapLoadbalancerToAmphora(BaseDatabaseTask):
     """Maps and assigns a load balancer to an amphora in the database."""
 
-    def execute(self, loadbalancer_id, server_group_id=None, flavor=None):
+    def execute(self, loadbalancer_id, server_group_id=None, flavor=None,
+                availability_zone=None):
         """Allocates an Amphora for the load balancer in the database.
 
         :param loadbalancer_id: The load balancer id to map to an amphora
@@ -525,14 +523,20 @@ class MapLoadbalancerToAmphora(BaseDatabaseTask):
                       "allocation.")
             return None
 
+        if availability_zone:
+            amp_az = availability_zone.get(constants.COMPUTE_ZONE)
+        else:
+            amp_az = CONF.nova.availability_zone
+
         try:
             amp = self.amphora_repo.allocate_and_associate(
                 db_apis.get_session(),
-                loadbalancer_id)
+                loadbalancer_id,
+                amp_az)
         except Exception as e:
-            LOG.error("Failed to get a spare amphora for "
+            LOG.error("Failed to get a spare amphora (AZ: {}) for "
                       "loadbalancer {} due to: {}".format(
-                          loadbalancer_id, e))
+                          amp_az, loadbalancer_id, e))
             return None
 
         if amp is None:
@@ -931,7 +935,7 @@ class UpdateAmphoraDBCertExpiration(BaseDatabaseTask):
 
         LOG.debug("Update DB cert expiry date of amphora id: %s", amphora_id)
 
-        key = utils.get_six_compatible_server_certs_key_passphrase()
+        key = utils.get_compatible_server_certs_key_passphrase()
         fer = fernet.Fernet(key)
         cert_expiration = cert_parser.get_cert_expiration(
             fer.decrypt(server_pem))
@@ -1187,7 +1191,7 @@ class MarkLBAndListenersActiveInDB(BaseDatabaseTask):
 
         LOG.debug("Mark ACTIVE in DB for load balancer id: %s "
                   "and updating status for listener ids: %s", loadbalancer.id,
-                  ', '.join([l.id for l in listeners]))
+                  ', '.join([listener.id for listener in listeners]))
         self.loadbalancer_repo.update(db_apis.get_session(),
                                       loadbalancer.id,
                                       provisioning_status=constants.ACTIVE)
@@ -1206,7 +1210,8 @@ class MarkLBAndListenersActiveInDB(BaseDatabaseTask):
         LOG.warning("Reverting mark load balancer and listeners active in DB "
                     "for load balancer id %(LB)s and listener ids: %(list)s",
                     {'LB': loadbalancer.id,
-                     'list': ', '.join([l.id for l in listeners])})
+                     'list': ', '.join([listener.id
+                                        for listener in listeners])})
         self.task_utils.mark_loadbalancer_prov_status_error(loadbalancer.id)
         for listener in listeners:
             self.task_utils.mark_listener_prov_status_error(listener.id)
@@ -1539,17 +1544,15 @@ class GetAmphoraDetails(BaseDatabaseTask):
 
 
 class GetAmphoraeFromLoadbalancer(BaseDatabaseTask):
-    """Task to pull the amphorae from a loadbalancer."""
+    """Task to pull the listeners from a loadbalancer."""
 
-    def execute(self, loadbalancer_id):
+    def execute(self, loadbalancer):
         """Pull the amphorae from a loadbalancer.
 
-        :param loadbalancer_id: Load balancer ID to get amphorae from
+        :param loadbalancer: Load balancer which listeners are required
         :returns: A list of Listener objects
         """
         amphorae = []
-        loadbalancer = self.loadbalancer_repo.get(db_apis.get_session(),
-                                                  id=loadbalancer_id)
         for amp in loadbalancer.amphorae:
             a = self.amphora_repo.get(db_apis.get_session(), id=amp.id,
                                       show_deleted=False)
@@ -1576,22 +1579,6 @@ class GetListenersFromLoadbalancer(BaseDatabaseTask):
         return listeners
 
 
-class GetLoadBalancer(BaseDatabaseTask):
-    """Get an load balancer object from the database."""
-
-    def execute(self, loadbalancer_id, *args, **kwargs):
-        """Get an load balancer object from the database.
-
-        :param loadbalancer_id: The load balancer ID to lookup
-        :returns: The load balancer object
-        """
-
-        LOG.debug("Get load balancer from DB for load balancer id: %s",
-                  loadbalancer_id)
-        return self.loadbalancer_repo.get(db_apis.get_session(),
-                                          id=loadbalancer_id)
-
-
 class GetVipFromLoadbalancer(BaseDatabaseTask):
     """Task to pull the vip from a loadbalancer."""
 
@@ -1607,23 +1594,25 @@ class GetVipFromLoadbalancer(BaseDatabaseTask):
 class CreateVRRPGroupForLB(BaseDatabaseTask):
     """Create a VRRP group for a load balancer."""
 
-    def execute(self, loadbalancer_id):
+    def execute(self, loadbalancer):
         """Create a VRRP group for a load balancer.
 
-        :param loadbalancer_id: Load balancer ID for which a VRRP group
+        :param loadbalancer: Load balancer for which a VRRP group
                should be created
+        :returns: Updated load balancer
         """
         try:
-            self.repos.vrrpgroup.create(
+            loadbalancer.vrrp_group = self.repos.vrrpgroup.create(
                 db_apis.get_session(),
-                load_balancer_id=loadbalancer_id,
-                vrrp_group_name=str(loadbalancer_id).replace('-', ''),
+                load_balancer_id=loadbalancer.id,
+                vrrp_group_name=str(loadbalancer.id).replace('-', ''),
                 vrrp_auth_type=constants.VRRP_AUTH_DEFAULT,
                 vrrp_auth_pass=uuidutils.generate_uuid().replace('-', '')[0:7],
                 advert_int=CONF.keepalived_vrrp.vrrp_advert_int)
         except odb_exceptions.DBDuplicateEntry:
             LOG.debug('VRRP_GROUP entry already exists for load balancer, '
                       'skipping create.')
+        return loadbalancer
 
 
 class DisableAmphoraHealthMonitoring(BaseDatabaseTask):
@@ -2642,7 +2631,7 @@ class DecrementPoolQuota(BaseDatabaseTask):
                 # This is separate calls to maximize the correction
                 # should other factors have increased the in use quota
                 # before this point in the revert flow
-                for i in six.moves.range(pool_child_count['member']):
+                for i in range(pool_child_count['member']):
                     lock_session = db_apis.get_session(autocommit=False)
                     try:
                         self.repos.check_quota_met(session,
