@@ -23,6 +23,8 @@ from sqlalchemy.orm import validates
 from sqlalchemy.sql import func
 
 from octavia.api.v2.types import amphora
+from octavia.api.v2.types import availability_zone_profile
+from octavia.api.v2.types import availability_zones
 from octavia.api.v2.types import flavor_profile
 from octavia.api.v2.types import flavors
 from octavia.api.v2.types import health_monitor
@@ -334,6 +336,7 @@ class Pool(base_models.BASE, base_models.IdMixin, base_models.ProjectMixin,
     ca_tls_certificate_id = sa.Column(sa.String(255), nullable=True)
     crl_container_id = sa.Column(sa.String(255), nullable=True)
     tls_enabled = sa.Column(sa.Boolean, default=False, nullable=False)
+    tls_ciphers = sa.Column(sa.String(2048), nullable=True)
 
     # This property should be a unique list of any listeners that reference
     # this pool as its default_pool and any listeners referenced by enabled
@@ -343,13 +346,13 @@ class Pool(base_models.BASE, base_models.IdMixin, base_models.ProjectMixin,
     @property
     def listeners(self):
         _listeners = self._default_listeners[:]
-        _l_ids = [l.id for l in _listeners]
+        _l_ids = [li.id for li in _listeners]
         l7_listeners = [p.listener for p in self.l7policies
                         if len(p.l7rules) > 0 and p.enabled is True]
-        for l in l7_listeners:
-            if l.id not in _l_ids:
-                _listeners.append(l)
-                _l_ids.append(l.id)
+        for li in l7_listeners:
+            if li.id not in _l_ids:
+                _listeners.append(li)
+                _l_ids.append(li.id)
         return _listeners
 
 
@@ -399,6 +402,11 @@ class LoadBalancer(base_models.BASE, base_models.IdMixin,
     flavor_id = sa.Column(
         sa.String(36),
         sa.ForeignKey("flavor.id", name="fk_lb_flavor_id"), nullable=True)
+    availability_zone = sa.Column(
+        sa.String(255),
+        sa.ForeignKey("availability_zone.name",
+                      name="fk_load_balancer_availability_zone_name"),
+        nullable=True)
 
 
 class VRRPGroup(base_models.BASE):
@@ -492,8 +500,8 @@ class Listener(base_models.BASE, base_models.IdMixin,
     default_pool = orm.relationship("Pool", uselist=False,
                                     back_populates="_default_listeners")
     sni_containers = orm.relationship(
-        'SNI', cascade='all,delete-orphan',
-        uselist=True, backref=orm.backref('listener', uselist=False))
+        'SNI', cascade='delete', uselist=True,
+        backref=orm.backref('listener', uselist=False))
 
     l7policies = orm.relationship(
         'L7Policy', uselist=True, order_by='L7Policy.position',
@@ -513,6 +521,7 @@ class Listener(base_models.BASE, base_models.IdMixin,
                       name="fk_listener_client_authentication_mode_name"),
         nullable=False, default=constants.CLIENT_AUTH_NONE)
     client_crl_container_id = sa.Column(sa.String(255), nullable=True)
+    tls_ciphers = sa.Column(sa.String(2048), nullable=True)
 
     _tags = orm.relationship(
         'Tags',
@@ -782,6 +791,41 @@ class Flavor(base_models.BASE,
         nullable=False)
 
 
+class AvailabilityZoneProfile(base_models.BASE, base_models.IdMixin,
+                              base_models.NameMixin):
+
+    __data_model__ = data_models.AvailabilityZoneProfile
+
+    __tablename__ = "availability_zone_profile"
+
+    __v2_wsme__ = availability_zone_profile.AvailabilityZoneProfileResponse
+
+    provider_name = sa.Column(sa.String(255), nullable=False)
+    availability_zone_data = sa.Column(sa.String(4096), nullable=False)
+
+
+class AvailabilityZone(base_models.BASE,
+                       base_models.NameMixin):
+
+    __data_model__ = data_models.AvailabilityZone
+
+    __tablename__ = "availability_zone"
+
+    __v2_wsme__ = availability_zones.AvailabilityZoneResponse
+
+    __table_args__ = (
+        sa.PrimaryKeyConstraint('name'),
+    )
+
+    description = sa.Column(sa.String(255), nullable=True)
+    enabled = sa.Column(sa.Boolean(), nullable=False)
+    availability_zone_profile_id = sa.Column(
+        sa.String(36),
+        sa.ForeignKey("availability_zone_profile.id",
+                      name="fk_az_az_profile_id"),
+        nullable=False)
+
+
 class ClientAuthenticationMode(base_models.BASE):
 
     __tablename__ = "client_authentication_mode"
