@@ -120,7 +120,7 @@ class BaseNeutronDriver(base.AbstractNetworkDriver):
             raise base.NetworkException(str(e))
 
     def _get_ports_by_security_group(self, sec_grp_id):
-        all_ports = self.neutron_client.list_ports(project=self.project_id)
+        all_ports = self.neutron_client.list_ports(project_id=self.project_id)
         filtered_ports = []
         for port in all_ports.get('ports', []):
             if sec_grp_id in port.get('security_groups', []):
@@ -134,7 +134,8 @@ class BaseNeutronDriver(base.AbstractNetworkDriver):
 
     def _create_security_group_rule(self, sec_grp_id, protocol,
                                     direction='ingress', port_min=None,
-                                    port_max=None, ethertype='IPv6'):
+                                    port_max=None, ethertype='IPv6',
+                                    cidr=None):
         rule = {
             'security_group_rule': {
                 'security_group_id': sec_grp_id,
@@ -143,8 +144,10 @@ class BaseNeutronDriver(base.AbstractNetworkDriver):
                 'port_range_min': port_min,
                 'port_range_max': port_max,
                 'ethertype': ethertype,
+                'remote_ip_prefix': cidr,
             }
         }
+
         self.neutron_client.create_security_group_rule(rule)
 
     def apply_qos_on_port(self, qos_id, port_id):
@@ -209,11 +212,11 @@ class BaseNeutronDriver(base.AbstractNetworkDriver):
             if not resource['%ss' % resource_type]:
                 # no items found
                 raise neutron_client_exceptions.NotFound()
-            elif unique_item:
+            if unique_item:
                 return conversion_function(resource['%ss' % resource_type][0])
-            else:
-                return list(map(conversion_function,
-                                resource['%ss' % resource_type]))
+
+            return list(map(conversion_function,
+                            resource['%ss' % resource_type]))
         except neutron_client_exceptions.NotFound:
             message = _('{resource_type} not found '
                         '({resource_type} Filters: {filters}.').format(
