@@ -12,7 +12,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 from octavia_lib.api.drivers import data_models as driver_dm
 from oslo_config import cfg
 from oslo_config import fixture as oslo_fixture
@@ -211,45 +212,6 @@ class TestMember(base.BaseAPITest):
         for m in [api_m_1, api_m_2]:
             self.assertIn(m, response)
 
-    def test_get_all_unscoped_token(self):
-        api_m_1 = self.create_member(
-            self.pool_id, '192.0.2.1', 80).get(self.root_tag)
-        self.set_lb_status(self.lb_id)
-        api_m_2 = self.create_member(
-            self.pool_id, '192.0.2.2', 80).get(self.root_tag)
-        self.set_lb_status(self.lb_id)
-        # Original objects didn't have the updated operating/provisioning
-        # status that exists in the DB.
-        for m in [api_m_1, api_m_2]:
-            m['operating_status'] = constants.ONLINE
-            m['provisioning_status'] = constants.ACTIVE
-            m.pop('updated_at')
-
-        self.conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
-        auth_strategy = self.conf.conf.api_settings.get('auth_strategy')
-        self.conf.config(group='api_settings', auth_strategy=constants.TESTING)
-        with mock.patch.object(octavia.common.context.Context, 'project_id',
-                               None):
-            override_credentials = {
-                'service_user_id': None,
-                'user_domain_id': None,
-                'is_admin_project': True,
-                'service_project_domain_id': None,
-                'service_project_id': None,
-                'roles': ['load-balancer_member'],
-                'user_id': None,
-                'is_admin': False,
-                'service_user_domain_id': None,
-                'project_domain_id': None,
-                'service_roles': [],
-                'project_id': None}
-            with mock.patch(
-                    "oslo_context.context.RequestContext.to_policy_values",
-                    return_value=override_credentials):
-                result = self.get(self.members_path, status=403).json
-        self.conf.config(group='api_settings', auth_strategy=auth_strategy)
-        self.assertEqual(self.NOT_AUTHORIZED_BODY, result)
-
     def test_get_all_not_authorized(self):
         api_m_1 = self.create_member(
             self.pool_id, '192.0.2.1', 80).get(self.root_tag)
@@ -332,7 +294,8 @@ class TestMember(base.BaseAPITest):
         links = middle[self.root_tag_links]
         self.assertEqual(1, len(objs))
         self.assertEqual(2, len(links))
-        self.assertItemsEqual(['previous', 'next'], [l['rel'] for l in links])
+        self.assertItemsEqual(['previous', 'next'],
+                              [link['rel'] for link in links])
 
     def test_get_all_fields_filter(self):
         self.create_member(self.pool_id, '192.0.2.1', 80, name='member1')
@@ -682,7 +645,7 @@ class TestMember(base.BaseAPITest):
 
         mock_provider.assert_called_once_with(u'noop_driver',
                                               mock_driver.member_batch_update,
-                                              provider_creates)
+                                              self.pool_id, provider_creates)
 
     @mock.patch('octavia.api.drivers.driver_factory.get_driver')
     @mock.patch('octavia.api.drivers.utils.call_provider')
@@ -725,7 +688,7 @@ class TestMember(base.BaseAPITest):
 
         mock_provider.assert_called_once_with(u'noop_driver',
                                               mock_driver.member_batch_update,
-                                              provider_members)
+                                              self.pool_id, provider_members)
 
     def test_create_batch_members_with_bad_subnet(self):
         subnet_id = uuidutils.generate_uuid()
@@ -827,7 +790,7 @@ class TestMember(base.BaseAPITest):
 
         mock_provider.assert_called_once_with(u'noop_driver',
                                               mock_driver.member_batch_update,
-                                              provider_creates)
+                                              self.pool_id, provider_creates)
 
     @mock.patch('octavia.api.drivers.driver_factory.get_driver')
     @mock.patch('octavia.api.drivers.utils.call_provider')
@@ -878,7 +841,7 @@ class TestMember(base.BaseAPITest):
 
         mock_provider.assert_called_once_with(u'noop_driver',
                                               mock_driver.member_batch_update,
-                                              provider_members)
+                                              self.pool_id, provider_members)
 
     @mock.patch('octavia.api.drivers.driver_factory.get_driver')
     @mock.patch('octavia.api.drivers.utils.call_provider')
@@ -920,7 +883,29 @@ class TestMember(base.BaseAPITest):
 
         mock_provider.assert_called_once_with(u'noop_driver',
                                               mock_driver.member_batch_update,
-                                              provider_members)
+                                              self.pool_id, provider_members)
+
+    @mock.patch('octavia.api.drivers.driver_factory.get_driver')
+    @mock.patch('octavia.api.drivers.utils.call_provider')
+    def test_delete_batch_members_already_empty(self, mock_provider,
+                                                mock_get_driver):
+        mock_driver = mock.MagicMock()
+        mock_driver.name = 'noop_driver'
+        mock_get_driver.return_value = mock_driver
+
+        req_dict = []
+        body = {self.root_tag_list: req_dict}
+        path = self.MEMBERS_PATH.format(pool_id=self.pool_id)
+        self.put(path, body, status=202)
+        returned_members = self.get(
+            self.MEMBERS_PATH.format(pool_id=self.pool_id)
+        ).json.get(self.root_tag_list)
+
+        self.assertEqual([], returned_members)
+
+        mock_provider.assert_called_once_with(u'noop_driver',
+                                              mock_driver.member_batch_update,
+                                              self.pool_id, [])
 
     def test_create_with_attached_listener(self):
         api_member = self.create_member(
