@@ -295,7 +295,7 @@ RET_LISTENER = {
     'protocol': 'HTTP',
     'protocol_mode': 'http',
     'default_pool': RET_POOL_1,
-    'connection_limit': constants.HAPROXY_DEFAULT_MAXCONN,
+    'connection_limit': constants.HAPROXY_MAX_MAXCONN,
     'user_log_format': '12345\\ sample_loadbalancer_id_1\\ %f\\ %ci\\ %cp\\ '
                        '%t\\ %{+Q}r\\ %ST\\ %B\\ %U\\ %[ssl_c_verify]\\ '
                        '%{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ %tsc',
@@ -315,7 +315,7 @@ RET_LISTENER_L7 = {
     'protocol': 'HTTP',
     'protocol_mode': 'http',
     'default_pool': RET_POOL_1,
-    'connection_limit': constants.HAPROXY_DEFAULT_MAXCONN,
+    'connection_limit': constants.HAPROXY_MAX_MAXCONN,
     'user_log_format': '12345\\ sample_loadbalancer_id_1\\ %f\\ %ci\\ %cp\\ '
                        '%t\\ %{+Q}r\\ %ST\\ %B\\ %U\\ %[ssl_c_verify]\\ '
                        '%{+Q}[ssl_c_s_dn]\\ %b\\ %s\\ %Tt\\ %tsc',
@@ -337,7 +337,7 @@ RET_LISTENER_TLS = {
     'protocol': 'TERMINATED_HTTPS',
     'protocol_mode': 'http',
     'default_pool': RET_POOL_1,
-    'connection_limit': constants.HAPROXY_DEFAULT_MAXCONN,
+    'connection_limit': constants.HAPROXY_MAX_MAXCONN,
     'tls_certificate_id': 'cont_id_1',
     'default_tls_path': '/etc/ssl/sample_loadbalancer_id_1/fakeCN.pem',
     'default_tls_container': RET_DEF_TLS_CONT,
@@ -349,10 +349,9 @@ RET_LISTENER_TLS = {
 RET_LISTENER_TLS_SNI = {
     'id': 'sample_listener_id_1',
     'protocol_port': '443',
-    'protocol': 'http',
     'protocol': 'TERMINATED_HTTPS',
     'default_pool': RET_POOL_1,
-    'connection_limit': constants.HAPROXY_DEFAULT_MAXCONN,
+    'connection_limit': constants.HAPROXY_MAX_MAXCONN,
     'tls_certificate_id': 'cont_id_1',
     'default_tls_path': '/etc/ssl/sample_loadbalancer_id_1/fakeCN.pem',
     'default_tls_container': RET_DEF_TLS_CONT,
@@ -384,7 +383,7 @@ RET_LB = {
     'peer_port': 1024,
     'topology': 'SINGLE',
     'enabled': True,
-    'global_connection_limit': constants.HAPROXY_DEFAULT_MAXCONN,
+    'global_connection_limit': constants.HAPROXY_MAX_MAXCONN,
     'amphorae': [sample_amphora_tuple()]}
 
 RET_LB_L7 = {
@@ -395,7 +394,7 @@ RET_LB_L7 = {
     'peer_port': 1024,
     'topology': 'SINGLE',
     'enabled': True,
-    'global_connection_limit': constants.HAPROXY_DEFAULT_MAXCONN,
+    'global_connection_limit': constants.HAPROXY_MAX_MAXCONN,
     'amphorae': [sample_amphora_tuple()]}
 
 UDP_SOURCE_IP_BODY = {
@@ -469,7 +468,7 @@ RET_UDP_POOL = {
     'id': 'sample_pool_id_1',
     'enabled': True,
     'health_monitor': UDP_HEALTH_MONITOR_NO_SCRIPT,
-    'lb_algorithm': 'wrr',
+    'lb_algorithm': 'rr',
     'members': [UDP_MEMBER_1, UDP_MEMBER_2],
     'protocol': 'udp',
     'session_persistence': UDP_SOURCE_IP_BODY
@@ -481,7 +480,7 @@ RET_UDP_LISTENER = {
         'id': 'sample_pool_id_1',
         'enabled': True,
         'health_monitor': RET_UDP_HEALTH_MONITOR,
-        'lb_algorithm': 'wrr',
+        'lb_algorithm': 'rr',
         'members': [UDP_MEMBER_1, UDP_MEMBER_2],
         'protocol': 'udp',
         'session_persistence': UDP_SOURCE_IP_BODY
@@ -589,9 +588,9 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                           tls=False, sni=False, peer_port=None, topology=None,
                           l7=False, enabled=True, insert_headers=None,
                           be_proto=None, monitor_ip_port=False,
-                          monitor_proto=None, backup_member=False,
-                          disabled_member=False,
-                          connection_limit=constants.DEFAULT_CONNECTION_LIMIT,
+                          monitor_proto=None, monitor_expected_codes=None,
+                          backup_member=False, disabled_member=False,
+                          connection_limit=-1,
                           timeout_client_data=50000,
                           timeout_member_connect=5000,
                           timeout_member_data=50000,
@@ -602,13 +601,15 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                           tls_enabled=False, hm_host_http_check=False,
                           id='sample_listener_id_1', recursive_nest=False,
                           provisioning_status=constants.ACTIVE,
-                          sample_default_pool=1,
-                          pool_enabled=True):
+                          tls_ciphers=constants.CIPHERS_OWASP_SUITE_B,
+                          backend_tls_ciphers=None):
     proto = 'HTTP' if proto is None else proto
     if be_proto is None:
-        be_proto = 'HTTP' if proto is 'TERMINATED_HTTPS' else proto
+        be_proto = 'HTTP' if proto == 'TERMINATED_HTTPS' else proto
+    if proto != constants.PROTOCOL_TERMINATED_HTTPS:
+        tls_ciphers = None
     topology = 'SINGLE' if topology is None else topology
-    port = '443' if proto is 'HTTPS' or proto is 'TERMINATED_HTTPS' else '80'
+    port = '443' if proto in ['HTTPS', 'TERMINATED_HTTPS'] else '80'
     peer_port = 1024 if peer_port is None else peer_port
     insert_headers = insert_headers or {}
     in_listener = collections.namedtuple(
@@ -620,7 +621,8 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                     'timeout_member_connect, timeout_member_data, '
                     'timeout_tcp_inspect, client_ca_tls_certificate_id, '
                     'client_ca_tls_certificate, client_authentication, '
-                    'client_crl_container_id, provisioning_status')
+                    'client_crl_container_id, provisioning_status, '
+                    'tls_ciphers')
     if l7:
         pools = [
             sample_pool_tuple(
@@ -632,7 +634,7 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                 pool_crl=pool_crl, tls_enabled=tls_enabled,
                 hm_host_http_check=hm_host_http_check,
                 listener_id='sample_listener_id_1',
-                enabled=pool_enabled),
+                tls_ciphers=backend_tls_ciphers),
             sample_pool_tuple(
                 proto=be_proto, monitor=monitor, persistence=persistence,
                 persistence_type=persistence_type,
@@ -642,7 +644,7 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                 pool_crl=pool_crl, tls_enabled=tls_enabled,
                 hm_host_http_check=hm_host_http_check,
                 listener_id='sample_listener_id_1',
-                enabled=pool_enabled)]
+                tls_ciphers=backend_tls_ciphers)]
         l7policies = [
             sample_l7policy_tuple('sample_l7policy_id_1', sample_policy=1),
             sample_l7policy_tuple('sample_l7policy_id_2', sample_policy=2),
@@ -666,7 +668,7 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
                 pool_crl=pool_crl, tls_enabled=tls_enabled,
                 hm_host_http_check=hm_host_http_check,
                 listener_id='sample_listener_id_1',
-                enabled=pool_enabled)]
+                tls_ciphers=backend_tls_ciphers)]
         l7policies = []
     listener = in_listener(
         id=id,
@@ -685,13 +687,12 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
             persistence_granularity=persistence_granularity,
             monitor_ip_port=monitor_ip_port,
             monitor_proto=monitor_proto,
+            monitor_expected_codes=monitor_expected_codes,
             pool_cert=pool_cert,
             pool_ca_cert=pool_ca_cert,
             pool_crl=pool_crl,
             tls_enabled=tls_enabled,
-            hm_host_http_check=hm_host_http_check,
-            sample_pool=sample_default_pool,
-            enabled=pool_enabled
+            hm_host_http_check=hm_host_http_check
         ) if alloc_default_pool else '',
         connection_limit=connection_limit,
         tls_certificate_id='cont_id_1' if tls else '',
@@ -736,6 +737,7 @@ def sample_listener_tuple(proto=None, monitor=True, alloc_default_pool=True,
             constants.CLIENT_AUTH_NONE),
         client_crl_container_id='cont_id_crl' if client_crl_cert else '',
         provisioning_status=provisioning_status,
+        tls_ciphers=tls_ciphers
     )
     if recursive_nest:
         listener.load_balancer.listeners.append(listener)
@@ -769,20 +771,24 @@ def sample_pool_tuple(listener_id=None, proto=None, monitor=True,
                       persistence_cookie=None, persistence_timeout=None,
                       persistence_granularity=None, sample_pool=1,
                       monitor_ip_port=False, monitor_proto=None,
+                      monitor_expected_codes=None,
                       backup_member=False, disabled_member=False,
                       has_http_reuse=True, pool_cert=False, pool_ca_cert=False,
                       pool_crl=False, tls_enabled=False,
                       hm_host_http_check=False,
                       provisioning_status=constants.ACTIVE,
-                      enabled=True):
+                      tls_ciphers=constants.CIPHERS_OWASP_SUITE_B):
     proto = 'HTTP' if proto is None else proto
+    if not tls_enabled:
+        tls_ciphers = None
     monitor_proto = proto if monitor_proto is None else monitor_proto
     in_pool = collections.namedtuple(
         'pool', 'id, protocol, lb_algorithm, members, health_monitor, '
                 'session_persistence, enabled, operating_status, '
                 'tls_certificate_id, ca_tls_certificate_id, '
-                'crl_container_id, tls_enabled, '
-                'provisioning_status, ' + constants.HTTP_REUSE)
+                'crl_container_id, tls_enabled, tls_ciphers, '
+                'provisioning_status, ' +
+                constants.HTTP_REUSE)
     if (proto == constants.PROTOCOL_UDP and
             persistence_type == constants.SESSION_PERSISTENCE_SOURCE_IP):
         kwargs = {'persistence_type': persistence_type,
@@ -793,13 +799,7 @@ def sample_pool_tuple(listener_id=None, proto=None, monitor=True,
                   'persistence_cookie': persistence_cookie}
     persis = sample_session_persistence_tuple(**kwargs)
     mon = None
-    if sample_pool == 0:
-        id = 'sample_pool_id_0'
-        members = []
-        if monitor is True:
-            mon = sample_health_monitor_tuple(
-                proto=monitor_proto, host_http_check=hm_host_http_check)
-    elif sample_pool == 1:
+    if sample_pool == 1:
         id = 'sample_pool_id_1'
         members = [sample_member_tuple('sample_member_id_1', '10.0.0.99',
                                        monitor_ip_port=monitor_ip_port),
@@ -809,7 +809,9 @@ def sample_pool_tuple(listener_id=None, proto=None, monitor=True,
                                        enabled=not disabled_member)]
         if monitor is True:
             mon = sample_health_monitor_tuple(
-                proto=monitor_proto, host_http_check=hm_host_http_check)
+                proto=monitor_proto,
+                host_http_check=hm_host_http_check,
+                expected_codes=monitor_expected_codes)
     elif sample_pool == 2:
         id = 'sample_pool_id_2'
         members = [sample_member_tuple('sample_member_id_3', '10.0.0.97',
@@ -817,7 +819,8 @@ def sample_pool_tuple(listener_id=None, proto=None, monitor=True,
         if monitor is True:
             mon = sample_health_monitor_tuple(
                 proto=monitor_proto, sample_hm=2,
-                host_http_check=hm_host_http_check)
+                host_http_check=hm_host_http_check,
+                expected_codes=monitor_expected_codes)
     return in_pool(
         id=id,
         protocol=proto,
@@ -825,12 +828,13 @@ def sample_pool_tuple(listener_id=None, proto=None, monitor=True,
         members=members,
         health_monitor=mon,
         session_persistence=persis if persistence is True else None,
-        enabled=enabled,
+        enabled=True,
         operating_status='ACTIVE', has_http_reuse=has_http_reuse,
         tls_certificate_id='pool_cont_1' if pool_cert else None,
         ca_tls_certificate_id='pool_ca_1' if pool_ca_cert else None,
         crl_container_id='pool_crl' if pool_crl else None,
         tls_enabled=tls_enabled,
+        tls_ciphers=tls_ciphers,
         provisioning_status=provisioning_status)
 
 
@@ -874,9 +878,9 @@ def sample_session_persistence_tuple(persistence_type=None,
 
 
 def sample_health_monitor_tuple(proto='HTTP', sample_hm=1,
-                                host_http_check=False,
+                                host_http_check=False, expected_codes=None,
                                 provisioning_status=constants.ACTIVE):
-    proto = 'HTTP' if proto is 'TERMINATED_HTTPS' else proto
+    proto = 'HTTP' if proto == 'TERMINATED_HTTPS' else proto
     monitor = collections.namedtuple(
         'monitor', 'id, type, delay, timeout, fall_threshold, rise_threshold,'
                    'http_method, url_path, expected_codes, enabled, '
@@ -906,6 +910,8 @@ def sample_health_monitor_tuple(proto='HTTP', sample_hm=1,
         kwargs.update({'http_version': 1.1, 'domain_name': 'testlab.com'})
     else:
         kwargs.update({'http_version': 1.0, 'domain_name': None})
+    if expected_codes:
+        kwargs.update({'expected_codes': expected_codes})
     if proto == constants.HEALTH_MONITOR_UDP_CONNECT:
         kwargs['check_script_path'] = (CONF.haproxy_amphora.base_path +
                                        'lvs/check/' + 'udp_check.sh')
@@ -1075,7 +1081,7 @@ def sample_base_expected_config(frontend=None, logging=None, backend=None,
                     "    default_backend sample_pool_id_1:sample_listener_id_1"
                     "\n"
                     "    timeout client 50000\n").format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
     if logging is None:
         logging = ("    log-format 12345\\ sample_loadbalancer_id_1\\ %f\\ "
                    "%ci\\ %cp\\ %t\\ %{+Q}r\\ %ST\\ %B\\ %U\\ "
@@ -1097,13 +1103,13 @@ def sample_base_expected_config(frontend=None, logging=None, backend=None,
                    "check inter 30s fall 3 rise 2 cookie sample_member_id_1\n"
                    "    server sample_member_id_2 10.0.0.98:82 weight 13 "
                    "check inter 30s fall 3 rise 2 cookie sample_member_id_2\n"
-                   "\n").format(maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+                   "\n").format(maxconn=constants.HAPROXY_MAX_MAXCONN)
 
     if peers is None:
         peers = "\n\n"
     if global_opts is None:
         global_opts = "    maxconn {maxconn}\n\n".format(
-            maxconn=constants.HAPROXY_DEFAULT_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN)
     if defaults is None:
         defaults = ("defaults\n"
                     "    log global\n"
